@@ -16,6 +16,7 @@
 /* #undef OGRE_BUILD_PLUGIN_CG */
 /* #undef OGRE_BUILD_PLUGIN_GLSLANG */
 #define OGRE_BUILD_PLUGIN_STBI
+/* #undef OGRE_BUILD_PLUGIN_RSIMAGE */
 #define OGRE_BUILD_PLUGIN_FREEIMAGE
 #define OGRE_BUILD_PLUGIN_DOT_SCENE
 #define OGRE_BUILD_COMPONENT_PAGING
@@ -25,7 +26,7 @@
 #define OGRE_BUILD_COMPONENT_PROPERTY
 #define OGRE_BUILD_COMPONENT_OVERLAY
 #define OGRE_BUILD_COMPONENT_RTSHADERSYSTEM
-/* #undef OGRE_BUILD_COMPONENT_BULLET */
+#define OGRE_BUILD_COMPONENT_BULLET
 
 #define OGRE_BITES_HAVE_SDL 1
 
