@@ -4,16 +4,19 @@ var _ogre_prerequisites_8h =
     [ "OGRE_TOKEN_PASTE", "_ogre_prerequisites_8h.html#aadfaee1c10a53055c49ad591cbbb9e38", null ],
     [ "OGRE_VERSION", "_ogre_prerequisites_8h.html#a3f631403da0a255c201870bfd068f8c5", null ],
     [ "OGRE_MIN_VERSION", "_ogre_prerequisites_8h.html#adacb0b9741bc9e705bc271031d379aa5", null ],
+    [ "_OgreMaybeExport", "_ogre_prerequisites_8h.html#adad9237308cc716c4b11a8f7a6b5669f", null ],
     [ "Real", "_ogre_prerequisites_8h.html#aa3a7b6dfb905e6572d62f0dfa3d4274d", null ],
     [ "uchar", "_ogre_prerequisites_8h.html#a07f1f7c1d84d58c9beae02e1ebb945e4", null ],
     [ "ushort", "_ogre_prerequisites_8h.html#af851e71354d841df7138f9877c6f5931", null ],
     [ "uint", "_ogre_prerequisites_8h.html#ab6e842a18caf062ed73a5d3badd0dd4c", null ],
     [ "ulong", "_ogre_prerequisites_8h.html#a4304981347643708ee9a7ba8884e5758", null ],
-    [ "ControllerReal", "_ogre_prerequisites_8h.html#adba71c6f0978281426bce794efea2537", null ],
+    [ "ControllerFloat", "_ogre_prerequisites_8h.html#ac6dc520d867be5f194779cc09f54b64c", null ],
+    [ "ControllerReal", "_ogre_prerequisites_8h.html#ad77c78fa5a8b5e62550f970a8905c509", null ],
     [ "HighLevelGpuProgramFactory", "_ogre_prerequisites_8h.html#a5ac5c5141120da7735f8f151b29a1d47", null ],
     [ "HighLevelGpuProgramManager", "_ogre_prerequisites_8h.html#abce10692dd9c7b0e2b8033a7476c2358", null ],
     [ "ParticleSystemRendererFactory", "_ogre_prerequisites_8h.html#ab68581d765ec12b3eb68b9270c5113f5", null ],
     [ "Vector2", "_ogre_prerequisites_8h.html#a8542e5da4c0e0bda0d0bf5745329ea88", null ],
+    [ "Vector2f", "_ogre_prerequisites_8h.html#a17ac50f71e23ddbc3bb8e34c6b4007da", null ],
     [ "Vector2i", "_ogre_prerequisites_8h.html#aa45059cb355996532a0ca37f0be9bc98", null ],
     [ "Vector3", "_ogre_prerequisites_8h.html#ac94fc4008c1165dea017263fee56b273", null ],
     [ "Vector3f", "_ogre_prerequisites_8h.html#aee06b1224b6eb1303888d8241d5c16ec", null ],
@@ -51,5 +54,22 @@ var _ogre_prerequisites_8h =
     [ "GpuProgramParametersSharedPtr", "_ogre_prerequisites_8h.html#aff0eec6634048fd4d65b785264243e6c", null ],
     [ "String", "_ogre_prerequisites_8h.html#aaf6cdc855bf9ae5edbf48a7e7dcb27f8", null ],
     [ "StringStream", "_ogre_prerequisites_8h.html#af9b3423b7c29049c4cfa637d4a41a28f", null ],
-    [ "aligned_vector", "_ogre_prerequisites_8h.html#a0dd9e0f32187e7f37d1e1fff9e3cb7cb", null ]
+    [ "aligned_vector", "_ogre_prerequisites_8h.html#aec93725f3ea0bb47424b11e401550e4a", null ],
+    [ "Vector", "_ogre_prerequisites_8h.html#ab8bbcab42b67b21ae639dd3ef57c2932", null ],
+    [ "MOT_ENTITY", "_ogre_prerequisites_8h.html#a465b857a17d8ebbbbef49e4ecccd5505", null ],
+    [ "MOT_LIGHT", "_ogre_prerequisites_8h.html#a31556cf3832442060ab4b33378d8f09d", null ],
+    [ "MOT_MANUAL_OBJECT", "_ogre_prerequisites_8h.html#a59d8863c4ce62021e0ec3aebda232422", null ],
+    [ "MOT_PARTICLE_SYSTEM", "_ogre_prerequisites_8h.html#a9297e4ba862a7506f0c1a62b26b59a24", null ],
+    [ "MOT_BILLBOARD_SET", "_ogre_prerequisites_8h.html#a70fa907104459ee375cbc6e0f43eeb74", null ],
+    [ "MOT_BILLBOARD_CHAIN", "_ogre_prerequisites_8h.html#a70291a99caf16ec1ce14ce4d03ed4f07", null ],
+    [ "MOT_RIBBON_TRAIL", "_ogre_prerequisites_8h.html#a3287ad729460d74b51f1100612dd50b9", null ],
+    [ "MOT_RECTANGLE2D", "_ogre_prerequisites_8h.html#aaeea8e914de95954f4ccbc680e633ac4", null ],
+    [ "MOT_STATIC_GEOMETRY", "_ogre_prerequisites_8h.html#a6d84a8d0d69f1c49ad30637016bccc80", null ],
+    [ "MOT_CAMERA", "_ogre_prerequisites_8h.html#afbd510273476ae6d23a3339542c3c63d", null ],
+    [ "MOT_FRUSTRUM", "_ogre_prerequisites_8h.html#a092f626940ed7d6e92b95db25c0be892", null ],
+    [ "MOT_FRUSTUM", "_ogre_prerequisites_8h.html#a793439fa964ffad99ec9ba1f2e4e9f91", null ],
+    [ "MOT_MOVABLE_PLANE", "_ogre_prerequisites_8h.html#a72f7c7ed96713df7ed929bc19c8f2f1b", null ],
+    [ "MOT_INSTANCE_BATCH", "_ogre_prerequisites_8h.html#a0cbbbb116f181c7ef9031b25ca3d2b92", null ],
+    [ "MOT_INSTANCED_ENTITY", "_ogre_prerequisites_8h.html#a9c21c25fe94d377e08de68d4502c90fd", null ],
+    [ "MOT_SIMPLE_RENDERABLE", "_ogre_prerequisites_8h.html#a99fb0d12485f50c22c3a63a4e060fcd7", null ]
 ];
\ No newline at end of file
