@@ -9,5 +9,7 @@ var class_ogre_1_1_d3_d11_texture =
     [ "GetTex1D", "class_ogre_1_1_d3_d11_texture.html#a167aaa10b49fb6cd486ba0f75b6cdd7a", null ],
     [ "GetTex2D", "class_ogre_1_1_d3_d11_texture.html#a1833eb88cf9f2e3cde4f913d6c214a7c", null ],
     [ "GetTex3D", "class_ogre_1_1_d3_d11_texture.html#a329628051791d3684ec1e4fa3a886d38", null ],
-    [ "HasAutoMipMapGenerationEnabled", "class_ogre_1_1_d3_d11_texture.html#afc89f37018b36db6bd839318d38ba434", null ]
+    [ "HasAutoMipMapGenerationEnabled", "class_ogre_1_1_d3_d11_texture.html#afc89f37018b36db6bd839318d38ba434", null ],
+    [ "createShaderAccessPoint", "class_ogre_1_1_d3_d11_texture.html#aeb5d057529c6c0994c0fc39b9579c878", null ],
+    [ "getUavView", "class_ogre_1_1_d3_d11_texture.html#a89fa9a6d9b3bababec169f6f55010150", null ]
 ];
\ No newline at end of file
