@@ -3,5 +3,6 @@ var class_ogre_1_1_g_l_s_l_program_manager_common =
     [ "GLSLProgramManagerCommon", "class_ogre_1_1_g_l_s_l_program_manager_common.html#a6db79bfcd62546902f11da7158d28cfc", null ],
     [ "~GLSLProgramManagerCommon", "class_ogre_1_1_g_l_s_l_program_manager_common.html#a7ff09badd2e7119d5c05c621809addb9", null ],
     [ "extractUniformsFromGLSL", "class_ogre_1_1_g_l_s_l_program_manager_common.html#ae8a109b69705dcab009b69f6334c58b1", null ],
-    [ "destroyAllByShader", "class_ogre_1_1_g_l_s_l_program_manager_common.html#af0074b30d327b54e5f352ca64612a043", null ]
+    [ "destroyAllByShader", "class_ogre_1_1_g_l_s_l_program_manager_common.html#af0074b30d327b54e5f352ca64612a043", null ],
+    [ "setActiveShader", "class_ogre_1_1_g_l_s_l_program_manager_common.html#a103fae6981db7f0eb836bd8c39b059d8", null ]
 ];
\ No newline at end of file
