@@ -1,8 +1,6 @@
 var class_ogre_1_1_scene_manager =
 [
-    [ "lightLess", "struct_ogre_1_1_scene_manager_1_1light_less.html", "struct_ogre_1_1_scene_manager_1_1light_less" ],
     [ "Listener", "class_ogre_1_1_scene_manager_1_1_listener.html", "class_ogre_1_1_scene_manager_1_1_listener" ],
-    [ "materialLess", "struct_ogre_1_1_scene_manager_1_1material_less.html", "struct_ogre_1_1_scene_manager_1_1material_less" ],
     [ "RenderContext", "struct_ogre_1_1_scene_manager_1_1_render_context.html", "struct_ogre_1_1_scene_manager_1_1_render_context" ],
     [ "SceneMgrQueuedRenderableVisitor", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor" ],
     [ "SkyBoxGenParameters", "struct_ogre_1_1_scene_manager_1_1_sky_box_gen_parameters.html", "struct_ogre_1_1_scene_manager_1_1_sky_box_gen_parameters" ],
@@ -11,6 +9,7 @@ var class_ogre_1_1_scene_manager =
     [ "CameraList", "class_ogre_1_1_scene_manager.html#a361c61a0f17ac50c8fd49bc0dd3ff622", null ],
     [ "AnimationList", "class_ogre_1_1_scene_manager.html#a260738557c9a32aed8d5ca14c28d300f", null ],
     [ "MovableObjectMap", "class_ogre_1_1_scene_manager.html#a317d0ca0b29d739ed54b4422f850b629", null ],
+    [ "StaticGeometryMap", "class_ogre_1_1_scene_manager.html#a0cd89dcbd8d830a2a3c03dac27f42c44", null ],
     [ "CameraIterator", "class_ogre_1_1_scene_manager.html#a22fcb8a9ddb7efe79d053a975a685111", null ],
     [ "AnimationIterator", "class_ogre_1_1_scene_manager.html#a3a720414f68274bb9c5026911e27135d", null ],
     [ "MovableObjectIterator", "class_ogre_1_1_scene_manager.html#a4249682ae2a69255ed225383d930aec1", null ],
@@ -32,11 +31,6 @@ var class_ogre_1_1_scene_manager =
       [ "SCRQM_INCLUDE", "class_ogre_1_1_scene_manager.html#a6aa3039230bf91b09b8587dba0c482c6a4f5291417680ce7d1715b7aef50869a7", null ],
       [ "SCRQM_EXCLUDE", "class_ogre_1_1_scene_manager.html#a6aa3039230bf91b09b8587dba0c482c6acc6b7e38cc21cf87a29e17177dc1a0b3", null ]
     ] ],
-    [ "PrefabType", "class_ogre_1_1_scene_manager.html#ab4c2ff4f6c76f7fe0a8eae76f2a84cbf", [
-      [ "PT_PLANE", "class_ogre_1_1_scene_manager.html#ab4c2ff4f6c76f7fe0a8eae76f2a84cbfaf0fb654fb98508a564c17d3d5b2feee3", null ],
-      [ "PT_CUBE", "class_ogre_1_1_scene_manager.html#ab4c2ff4f6c76f7fe0a8eae76f2a84cbfa25b0181d24b783ab75da2520305d292a", null ],
-      [ "PT_SPHERE", "class_ogre_1_1_scene_manager.html#ab4c2ff4f6c76f7fe0a8eae76f2a84cbfa0f94148c2cfe190f3ea04374af220eba", null ]
-    ] ],
     [ "SceneManager", "class_ogre_1_1_scene_manager.html#a09e76a674bc69c610fb49acd3da76cf1", null ],
     [ "~SceneManager", "class_ogre_1_1_scene_manager.html#a6c8b9108b44339a321bc69b25a0c0a1a", null ],
     [ "_pauseRendering", "class_ogre_1_1_scene_manager.html#a5c9816798bda78389efc4f071051c739", null ],
@@ -47,9 +41,9 @@ var class_ogre_1_1_scene_manager =
     [ "createCamera", "class_ogre_1_1_scene_manager.html#a9a394daa05374d05e4e378f540418c1f", null ],
     [ "getCamera", "class_ogre_1_1_scene_manager.html#a5d045c10d23adb73e03751505beb346a", null ],
     [ "hasCamera", "class_ogre_1_1_scene_manager.html#a3339b949a5f7927d80b48fb19044e1cb", null ],
-    [ "destroyCamera", "class_ogre_1_1_scene_manager.html#acac58e45f8b6b6826c81933f02a45046", null ],
-    [ "destroyCamera", "class_ogre_1_1_scene_manager.html#a41b9358cdad6fd7113b2a0cad8112f67", null ],
-    [ "destroyAllCameras", "class_ogre_1_1_scene_manager.html#a9cb93862284e7443b94eaabdef21564a", null ],
+    [ "destroyCamera", "class_ogre_1_1_scene_manager.html#a2038ca3f3b95a14152f26c6933f1a179", null ],
+    [ "destroyCamera", "class_ogre_1_1_scene_manager.html#af0c316e631cbbbb85137a328aee28b7c", null ],
+    [ "destroyAllCameras", "class_ogre_1_1_scene_manager.html#a710197d0688d6b3876984d595bdfa6ba", null ],
     [ "setCameraRelativeRendering", "class_ogre_1_1_scene_manager.html#af24677a56a91713c40c3bdb9025da38d", null ],
     [ "getCameraRelativeRendering", "class_ogre_1_1_scene_manager.html#acbf7af4f58966c776091f73c383ec2ae", null ],
     [ "getCameraIterator", "class_ogre_1_1_scene_manager.html#a02d7d29cc4bc8ee4cbe40d16a984291c", null ],
@@ -71,8 +65,8 @@ var class_ogre_1_1_scene_manager =
     [ "_getLightsAffectingFrustum", "class_ogre_1_1_scene_manager.html#aacb4f28f6f9ae731040c9d664da7d6ce", null ],
     [ "_populateLightList", "class_ogre_1_1_scene_manager.html#ad7330d1bfd3ed9700a1716151acbead3", null ],
     [ "_populateLightList", "class_ogre_1_1_scene_manager.html#ac6e42c947472bf09620ef974c3ac26a5", null ],
-    [ "createSceneNode", "class_ogre_1_1_scene_manager.html#a5afef854c959c49eae3216060066f1ae", null ],
-    [ "createSceneNode", "class_ogre_1_1_scene_manager.html#af5fffc742d127d0de1d5ecbba465abd8", null ],
+    [ "createSceneNode", "class_ogre_1_1_scene_manager.html#abb1b2745f8b8537434dbb1e9a8b4c020", null ],
+    [ "createSceneNode", "class_ogre_1_1_scene_manager.html#a4f17d2305cd0fc3e177d9264b9beda52", null ],
     [ "destroySceneNode", "class_ogre_1_1_scene_manager.html#aa613e5ffb08b95a90644a61ac10c9b5c", null ],
     [ "destroySceneNode", "class_ogre_1_1_scene_manager.html#a813346e505716ae5d24f714cfc4a5069", null ],
     [ "getRootSceneNode", "class_ogre_1_1_scene_manager.html#a7924f5a9ac983d29a5876d633f8a971d", null ],
@@ -87,13 +81,11 @@ var class_ogre_1_1_scene_manager =
     [ "createEntity", "class_ogre_1_1_scene_manager.html#a56882cf297909d38cb48b037dcbbfbd5", null ],
     [ "createEntity", "class_ogre_1_1_scene_manager.html#a2a3ac25a1d1639c641f5f09b7744ca70", null ],
     [ "createEntity", "class_ogre_1_1_scene_manager.html#af0c41f6c8b2bb2616e0e9b08d14231bf", null ],
-    [ "createEntity", "class_ogre_1_1_scene_manager.html#a169c75d89f8108bcdb33ddcde63d0451", null ],
-    [ "createEntity", "class_ogre_1_1_scene_manager.html#a5dd2bfa2cc1e18894913327f901f91e3", null ],
     [ "getEntity", "class_ogre_1_1_scene_manager.html#a5f5320728d8846ebe7ced3b972d37520", null ],
     [ "hasEntity", "class_ogre_1_1_scene_manager.html#a4a672aaeb3ede6c03e1b072d51e21b7a", null ],
     [ "destroyEntity", "class_ogre_1_1_scene_manager.html#adb544a5d5477ef91ef683e4ad5e7a39f", null ],
     [ "destroyEntity", "class_ogre_1_1_scene_manager.html#a59347bd0277c99dc2291965053aed4c6", null ],
-    [ "destroyAllEntities", "class_ogre_1_1_scene_manager.html#a1a77be68ccbfc90e2e1aed04340db4dc", null ],
+    [ "destroyAllEntities", "class_ogre_1_1_scene_manager.html#a8db7412fbb04789eb885c4d503614c0d", null ],
     [ "createManualObject", "class_ogre_1_1_scene_manager.html#ae8fffdc72f339e58be36ba97306cb432", null ],
     [ "createManualObject", "class_ogre_1_1_scene_manager.html#a81e0a45199422dd2e4f4ffd49fde482e", null ],
     [ "getManualObject", "class_ogre_1_1_scene_manager.html#a178db99889f05c98faae547f7c046c45", null ],
@@ -208,7 +200,7 @@ var class_ogre_1_1_scene_manager =
     [ "getSpecialCaseRenderQueueMode", "class_ogre_1_1_scene_manager.html#a24754c64740724fbbe901b0455d02639", null ],
     [ "isRenderQueueToBeProcessed", "class_ogre_1_1_scene_manager.html#a35f9c0406735f847c0588c7ce90a7e4c", null ],
     [ "setWorldGeometryRenderQueue", "class_ogre_1_1_scene_manager.html#acbc110b48a9c3a45f55a9c6d700fe847", null ],
-    [ "getWorldGeometryRenderQueue", "class_ogre_1_1_scene_manager.html#a663c32d37161a5eebf9cf8db3db8b052", null ],
+    [ "getWorldGeometryRenderQueue", "class_ogre_1_1_scene_manager.html#aba681db2b43ff006c48da59583b176df", null ],
     [ "_notifyAutotrackingSceneNode", "class_ogre_1_1_scene_manager.html#a436a99beba747d203841471d90e5be2e", null ],
     [ "createAABBQuery", "class_ogre_1_1_scene_manager.html#ae31e995656c34fdaa1c238efd65960b8", null ],
     [ "createSphereQuery", "class_ogre_1_1_scene_manager.html#a1859cb2e44f6d1423b263d3c34a69e6a", null ],
@@ -275,6 +267,7 @@ var class_ogre_1_1_scene_manager =
     [ "createStaticGeometry", "class_ogre_1_1_scene_manager.html#a89f2ca5ef5c9ba9856fdfcd0fadb0742", null ],
     [ "getStaticGeometry", "class_ogre_1_1_scene_manager.html#adb484fdb3b987874a0396c78e3a0a801", null ],
     [ "hasStaticGeometry", "class_ogre_1_1_scene_manager.html#acaf0c820efd7c9870d0630faea7013fa", null ],
+    [ "getStaticGeometryCollection", "class_ogre_1_1_scene_manager.html#a9c2c49f7ecf09c146944d37727d58a2e", null ],
     [ "destroyStaticGeometry", "class_ogre_1_1_scene_manager.html#af5bab37a967b021bb03c3c5d840b56ea", null ],
     [ "destroyStaticGeometry", "class_ogre_1_1_scene_manager.html#ac83d27698223cffeeafd19a9146f51f6", null ],
     [ "destroyAllStaticGeometry", "class_ogre_1_1_scene_manager.html#a5680c250fb35ab999e0d5d10b597216b", null ],
@@ -307,12 +300,10 @@ var class_ogre_1_1_scene_manager =
     [ "_getCombinedVisibilityMask", "class_ogre_1_1_scene_manager.html#a981ad410d5a077bb64938685e10fcee0", null ],
     [ "setFindVisibleObjects", "class_ogre_1_1_scene_manager.html#ab0a1beb3ad46d39d89d0338f2ec21558", null ],
     [ "getFindVisibleObjects", "class_ogre_1_1_scene_manager.html#a82ee334ba3818ff766463a74bfbf985c", null ],
-    [ "setNormaliseNormalsOnScale", "class_ogre_1_1_scene_manager.html#ae188c7cbe7a660db8b721f54a0ede2d1", null ],
-    [ "getNormaliseNormalsOnScale", "class_ogre_1_1_scene_manager.html#a55e33ede0c118d4dd3ba8cb62ff90496", null ],
     [ "setFlipCullingOnNegativeScale", "class_ogre_1_1_scene_manager.html#ae7115dce2e4a2c2dc49b0996b9279a21", null ],
     [ "getFlipCullingOnNegativeScale", "class_ogre_1_1_scene_manager.html#a15ff1cbfaa46b4c8786b80bcc7212488", null ],
     [ "_injectRenderWithPass", "class_ogre_1_1_scene_manager.html#a1593fab748d1b0820e93e49d5732350b", null ],
-    [ "_setPass", "class_ogre_1_1_scene_manager.html#a372fa399fb03d61cf71538fee63fa6e6", null ],
+    [ "_setPass", "class_ogre_1_1_scene_manager.html#a26901bfac04ed8a47ef92e3437f0e28d", null ],
     [ "_markGpuParamsDirty", "class_ogre_1_1_scene_manager.html#a9f1d305989a47813acb2300c208ce603", null ],
     [ "_renderQueueGroupObjects", "class_ogre_1_1_scene_manager.html#a6336349899e883a51d7446ef4cc3d9df", null ],
     [ "setQueuedRenderableVisitor", "class_ogre_1_1_scene_manager.html#af55b7d8cf3daf68db0266139faf73492", null ],
@@ -329,5 +320,8 @@ var class_ogre_1_1_scene_manager =
     [ "_handleLodEvents", "class_ogre_1_1_scene_manager.html#a72e39912a34617ffa0455f859ec438c3", null ],
     [ "_getCurrentRenderStage", "class_ogre_1_1_scene_manager.html#a027227b35d611d5b0f07ce0f93403b19", null ],
     [ "_getAutoParamDataSource", "class_ogre_1_1_scene_manager.html#ab681d6fe3691fbb8f964bbd6827dbfe2", null ],
-    [ "SceneMgrQueuedRenderableVisitor", "class_ogre_1_1_scene_manager.html#a25811fa0c23672b27dccfffd48bec43a", null ]
+    [ "SceneMgrQueuedRenderableVisitor", "class_ogre_1_1_scene_manager.html#a25811fa0c23672b27dccfffd48bec43a", null ],
+    [ "PT_PLANE", "class_ogre_1_1_scene_manager.html#aba1522f277022ea928223ef9bb8f2806", null ],
+    [ "PT_CUBE", "class_ogre_1_1_scene_manager.html#aeefb47c4d2f8b961381e9b25ab31c22d", null ],
+    [ "PT_SPHERE", "class_ogre_1_1_scene_manager.html#aa0adfbc6f313be8895a9f38872c76eaf", null ]
 ];
\ No newline at end of file
