@@ -34,10 +34,6 @@ var class_ogre_1_1_texture_unit_state =
       [ "CUBE_UP", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3ab085d126cff272045a1e616adbd2d726", null ],
       [ "CUBE_DOWN", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3a819e8a0cf0892c671d2fb4835780a12a", null ]
     ] ],
-    [ "BindingType", "class_ogre_1_1_texture_unit_state.html#a3d2985ccf0b6c78ed2ee996a4f464d7c", [
-      [ "BT_FRAGMENT", "class_ogre_1_1_texture_unit_state.html#a3d2985ccf0b6c78ed2ee996a4f464d7ca39c5f87a9b1c5873ece87f48cba19970", null ],
-      [ "BT_VERTEX", "class_ogre_1_1_texture_unit_state.html#a3d2985ccf0b6c78ed2ee996a4f464d7ca857de1fa5e307a5a5b0df779ad4a470e", null ]
-    ] ],
     [ "ContentType", "class_ogre_1_1_texture_unit_state.html#a3a09898645eac12548f6598fcbb9ac60", [
       [ "CONTENT_NAMED", "class_ogre_1_1_texture_unit_state.html#a3a09898645eac12548f6598fcbb9ac60a1bffc0ebc06c072fd00b5e032ba3ce01", null ],
       [ "CONTENT_SHADOW", "class_ogre_1_1_texture_unit_state.html#a3a09898645eac12548f6598fcbb9ac60a781de9de8d083db90677da1176d8ba82", null ],
@@ -46,7 +42,7 @@ var class_ogre_1_1_texture_unit_state =
     [ "TextureUnitState", "class_ogre_1_1_texture_unit_state.html#a310855c1a22c81688d276cbaf62bd1bb", null ],
     [ "TextureUnitState", "class_ogre_1_1_texture_unit_state.html#a474f19d881bffa023e05852ad94c727a", null ],
     [ "~TextureUnitState", "class_ogre_1_1_texture_unit_state.html#a21c2ac927f9f93472af7c8554c73bb0e", null ],
-    [ "TextureUnitState", "class_ogre_1_1_texture_unit_state.html#a9b8a41ad39710320e10738f0a7d96f0d", null ],
+    [ "TextureUnitState", "class_ogre_1_1_texture_unit_state.html#afab0a9f6644490148b096866e7ee3c9b", null ],
     [ "operator=", "class_ogre_1_1_texture_unit_state.html#a19ee8985d3012137dbf770ae172e193d", null ],
     [ "getTextureName", "class_ogre_1_1_texture_unit_state.html#a55e4e76b003d2b22bbdebb1d5daed2c7", null ],
     [ "setTextureName", "class_ogre_1_1_texture_unit_state.html#a74d4aec4c899121d19020f619c8b3873", null ],
@@ -67,8 +63,6 @@ var class_ogre_1_1_texture_unit_state =
     [ "addFrameTextureName", "class_ogre_1_1_texture_unit_state.html#a8532ad689770975afe46a3ddd49123a8", null ],
     [ "deleteFrameTextureName", "class_ogre_1_1_texture_unit_state.html#a7997d8a1385a7538a443c74d94a7cf75", null ],
     [ "getNumFrames", "class_ogre_1_1_texture_unit_state.html#a2f6eecd5b329f25365bd6b3a4050cd1b", null ],
-    [ "setBindingType", "class_ogre_1_1_texture_unit_state.html#a0ab7a2779ea196f2d51435d12a02d81f", null ],
-    [ "getBindingType", "class_ogre_1_1_texture_unit_state.html#a3b5783f584c51bed687ec033bda01f1c", null ],
     [ "setContentType", "class_ogre_1_1_texture_unit_state.html#adfaae68c0291e96fb75ba217d94e67bf", null ],
     [ "getContentType", "class_ogre_1_1_texture_unit_state.html#a1550b60ebc8506c725b1157e02c8eb6b", null ],
     [ "isCubic", "class_ogre_1_1_texture_unit_state.html#afe0aa6be6db7207ca6d439b6e52d33d8", null ],
@@ -83,8 +77,10 @@ var class_ogre_1_1_texture_unit_state =
     [ "setGamma", "class_ogre_1_1_texture_unit_state.html#a3859b558bf648b9825136156d9ebcae1", null ],
     [ "setHardwareGammaEnabled", "class_ogre_1_1_texture_unit_state.html#a09d08169e1c108c435fa595a227e87ad", null ],
     [ "isHardwareGammaEnabled", "class_ogre_1_1_texture_unit_state.html#a073cf9903b594cf1bb08b703934bf62d", null ],
-    [ "getTextureCoordSet", "class_ogre_1_1_texture_unit_state.html#a4b56b581407240e7b5139d779e1d2a8f", null ],
-    [ "setTextureCoordSet", "class_ogre_1_1_texture_unit_state.html#a70c55b5db14e54e2e7a991f548b6387d", null ],
+    [ "getTextureCoordSet", "class_ogre_1_1_texture_unit_state.html#a1ddd483565d6732053923d8534728077", null ],
+    [ "setTextureCoordSet", "class_ogre_1_1_texture_unit_state.html#aad59adb25e2890e019a092a808047923", null ],
+    [ "setUnorderedAccessMipLevel", "class_ogre_1_1_texture_unit_state.html#a742b42a23998723f38fc8757d0c0cb3d", null ],
+    [ "getUnorderedAccessMipLevel", "class_ogre_1_1_texture_unit_state.html#abb1668f6e6e0ae4239a6e2585dbca3fe", null ],
     [ "setTextureTransform", "class_ogre_1_1_texture_unit_state.html#ac7f99a83fe25f06af508b55e3ab381da", null ],
     [ "getTextureTransform", "class_ogre_1_1_texture_unit_state.html#ad61750224dd4b020b1490ea1daaf5077", null ],
     [ "setTextureScroll", "class_ogre_1_1_texture_unit_state.html#a354b3466d8c49e6f0057dea8206d3dd4", null ],
@@ -128,7 +124,7 @@ var class_ogre_1_1_texture_unit_state =
     [ "getColourBlendFallbackDest", "class_ogre_1_1_texture_unit_state.html#ab68978d806e23b1cf040d95d7231ba2e", null ],
     [ "setAlphaOperation", "class_ogre_1_1_texture_unit_state.html#ae5e48cac8f87dad78d040364021b7a95", null ],
     [ "addEffect", "class_ogre_1_1_texture_unit_state.html#a63fcdc07aea7a558c046c826ae510f39", null ],
-    [ "setEnvironmentMap", "class_ogre_1_1_texture_unit_state.html#a33ea31aeae9a25f1b05e2d987cbb891e", null ],
+    [ "setEnvironmentMap", "class_ogre_1_1_texture_unit_state.html#a7580913197a2a3ed270d291390fe2c21", null ],
     [ "setScrollAnimation", "class_ogre_1_1_texture_unit_state.html#a45bd669bcc64ec417fe4208aa5cfd685", null ],
     [ "setRotateAnimation", "class_ogre_1_1_texture_unit_state.html#a72e3695b81f12b32762237c5de202dff", null ],
     [ "setTransformAnimation", "class_ogre_1_1_texture_unit_state.html#af56112cb1e6d144b8fd63b280d8ae350", null ],
@@ -142,16 +138,15 @@ var class_ogre_1_1_texture_unit_state =
     [ "getEffects", "class_ogre_1_1_texture_unit_state.html#a9e312616adccbb8e58d0d4ef1dc1b277", null ],
     [ "getAnimationDuration", "class_ogre_1_1_texture_unit_state.html#a25b38aa2157538c8de784f46ab5442ac", null ],
     [ "isDefaultFiltering", "class_ogre_1_1_texture_unit_state.html#a5bb9b54d2869c429591b36f64d4361c5", null ],
-    [ "setCompositorReference", "class_ogre_1_1_texture_unit_state.html#a0073a4465cc92944252d69b2671ea97d", null ],
+    [ "setCompositorReference", "class_ogre_1_1_texture_unit_state.html#ad08cf1d92ff91a1e0befd3a06ed54f36", null ],
     [ "getReferencedCompositorName", "class_ogre_1_1_texture_unit_state.html#ae5a446b41e4fdcf6a2e39020b2027a68", null ],
     [ "getReferencedTextureName", "class_ogre_1_1_texture_unit_state.html#a7ce3bbc2cc302524d9a062839258d1b2", null ],
-    [ "getReferencedMRTIndex", "class_ogre_1_1_texture_unit_state.html#a4904a58094923e9cf9e7b7e0ced22bd9", null ],
+    [ "getReferencedMRTIndex", "class_ogre_1_1_texture_unit_state.html#a2361f4cb9d2221e1927e1be2005c828a", null ],
     [ "getParent", "class_ogre_1_1_texture_unit_state.html#aa393ef1656a11ff60795143402c81ea8", null ],
     [ "_prepare", "class_ogre_1_1_texture_unit_state.html#a9ba3e0f5bee6bc207eb8819cf18a793e", null ],
     [ "_unprepare", "class_ogre_1_1_texture_unit_state.html#a719be065c5457565e744410f3ec16a3f", null ],
     [ "_load", "class_ogre_1_1_texture_unit_state.html#a152b9706e34afd01006ccdd7e2ef7c99", null ],
     [ "_unload", "class_ogre_1_1_texture_unit_state.html#a1ad9f708a4e716ca5603bb96c61960ba", null ],
-    [ "hasViewRelativeTextureCoordinateGeneration", "class_ogre_1_1_texture_unit_state.html#a1a4084251e938a404d549ecb8f9db914", null ],
     [ "isLoaded", "class_ogre_1_1_texture_unit_state.html#a35e1d9894e9914eb725ab047bae276fd", null ],
     [ "_notifyNeedsRecompile", "class_ogre_1_1_texture_unit_state.html#a78895c49d27597bf3e11fc7269373124", null ],
     [ "setName", "class_ogre_1_1_texture_unit_state.html#abad476c32cafd8defc6f3c6da71dd2cb", null ],
@@ -164,12 +159,12 @@ var class_ogre_1_1_texture_unit_state =
     [ "_setTexturePtr", "class_ogre_1_1_texture_unit_state.html#abaa17fc5f6b4d96bfe19ecc6c78a331e", null ],
     [ "_setTexturePtr", "class_ogre_1_1_texture_unit_state.html#a6236e0e398c153980ff06f13e58a667b", null ],
     [ "calculateSize", "class_ogre_1_1_texture_unit_state.html#a2c9d0e4e1188041093e8b2c95dc07359", null ],
-    [ "_getAnimController", "class_ogre_1_1_texture_unit_state.html#a61315bdc457113996555bbf598b481a2", null ],
+    [ "_getAnimController", "class_ogre_1_1_texture_unit_state.html#ab84c56d8c8110240ad3af51bbe1b3645", null ],
     [ "_getLocalSampler", "class_ogre_1_1_texture_unit_state.html#a390667903c595896f59666cdedf7165d", null ],
+    [ "_deriveTexCoordCalcMethod", "class_ogre_1_1_texture_unit_state.html#aba208ea0411eb4b96f2f827b87c3d1da", null ],
     [ "RenderSystem", "class_ogre_1_1_texture_unit_state.html#a06b786d8e0847dfe9cc15e1dea308fcd", null ],
     [ "TAM_WRAP", "class_ogre_1_1_texture_unit_state.html#a9d12f77b02eacd0da7dcec2ac654c256", null ],
     [ "TAM_MIRROR", "class_ogre_1_1_texture_unit_state.html#a7f29d334eabef6ca15cc1e3a1d594467", null ],
     [ "TAM_CLAMP", "class_ogre_1_1_texture_unit_state.html#aaa593803cf70c8a67f24d4b74ad2ad77", null ],
-    [ "TAM_BORDER", "class_ogre_1_1_texture_unit_state.html#acced150b0dc0d1d64b0802dbe4cf7db1", null ],
-    [ "TAM_UNKNOWN", "class_ogre_1_1_texture_unit_state.html#a27d31e5a5ad06d018986d13b12fd4b41", null ]
+    [ "TAM_BORDER", "class_ogre_1_1_texture_unit_state.html#acced150b0dc0d1d64b0802dbe4cf7db1", null ]
 ];
\ No newline at end of file
