@@ -2,16 +2,16 @@ var group___volume =
 [
     [ "Ogre::Volume::CacheSource", "class_ogre_1_1_volume_1_1_cache_source.html", [
       [ "CacheSource", "class_ogre_1_1_volume_1_1_cache_source.html#a95bd0f55ff1d46ed19c13b2dcd87c5f7", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_cache_source.html#a8f36fb7c80678bc75b257ed3fa7dc420", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_cache_source.html#a3167f339581a63588a81987f09ba34eb", null ]
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_cache_source.html#ab7fbccea66760b79dd806408cad1b30c", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_cache_source.html#adbb0ad95d78e3105f78183fe71a935e5", null ]
     ] ],
     [ "Ogre::Volume::Chunk", "class_ogre_1_1_volume_1_1_chunk.html", [
       [ "VecChunk", "class_ogre_1_1_volume_1_1_chunk.html#a238954247d8ba6818c328fcf4820c90d", null ],
       [ "Chunk", "class_ogre_1_1_volume_1_1_chunk.html#a2667308a83b2df08493f91cc6c140efe", null ],
       [ "~Chunk", "class_ogre_1_1_volume_1_1_chunk.html#a0dcb5f2c15f452f96b4ed4dcc7ec9e28", null ],
-      [ "getMovableType", "class_ogre_1_1_volume_1_1_chunk.html#af00671e1fd3f9f32b20202c28a544a9f", null ],
-      [ "getSquaredViewDepth", "class_ogre_1_1_volume_1_1_chunk.html#ad9cdfe7c9e58b4bad34f5e71c63080f6", null ],
-      [ "getBoundingRadius", "class_ogre_1_1_volume_1_1_chunk.html#a79af172be0758f888ce9e86eccdcd5dd", null ],
+      [ "getMovableType", "class_ogre_1_1_volume_1_1_chunk.html#a6f2932953187ca60af068e586800a1ab", null ],
+      [ "getSquaredViewDepth", "class_ogre_1_1_volume_1_1_chunk.html#ad263d5e9e4699511723a3cf4954f829e", null ],
+      [ "getBoundingRadius", "class_ogre_1_1_volume_1_1_chunk.html#aadc4f2356b1224cc440968413c19b35a", null ],
       [ "load", "class_ogre_1_1_volume_1_1_chunk.html#a9557d5a30cbf29a46d4f8246a1e6d176", null ],
       [ "load", "class_ogre_1_1_volume_1_1_chunk.html#ab4fab49344ae8bd8976e13be5905449c", null ],
       [ "setDualGridVisible", "class_ogre_1_1_volume_1_1_chunk.html#a53b70a2524e1bbba07fc112b844a6bd8", null ],
@@ -20,23 +20,14 @@ var group___volume =
       [ "getOctreeVisible", "class_ogre_1_1_volume_1_1_chunk.html#af49fb98fabe407d9bba60197dc1c50e6", null ],
       [ "setVolumeVisible", "class_ogre_1_1_volume_1_1_chunk.html#a651c349120febbb1aa918d30125f0257", null ],
       [ "getVolumeVisible", "class_ogre_1_1_volume_1_1_chunk.html#a1d2036c97809818174f0fae0b128bde5", null ],
-      [ "frameStarted", "class_ogre_1_1_volume_1_1_chunk.html#acae8c3c6bac0462d6659dec3c7e5e364", null ],
+      [ "frameStarted", "class_ogre_1_1_volume_1_1_chunk.html#a53c42a0044fa53e3efa116bad19fc3f2", null ],
       [ "createInstance", "class_ogre_1_1_volume_1_1_chunk.html#a2e33708b9f9020c9f608de0de289016e", null ],
-      [ "setMaterial", "class_ogre_1_1_volume_1_1_chunk.html#a5129bccc53d17060635ada67443324f7", null ],
+      [ "setMaterial", "class_ogre_1_1_volume_1_1_chunk.html#af0c0c0b6684c8173253b791a72bca717", null ],
       [ "setMaterialOfLevel", "class_ogre_1_1_volume_1_1_chunk.html#a4cb0997e8d34b21e01e8f4d520ab56c6", null ],
       [ "getChunksOfLevel", "class_ogre_1_1_volume_1_1_chunk.html#aa52c1f2c5b5b39669eaee2bc11668a77", null ],
       [ "getChunkParameters", "class_ogre_1_1_volume_1_1_chunk.html#af8b5b17ef568308ba3f741708e9a0b00", null ],
-      [ "ChunkHandler", "class_ogre_1_1_volume_1_1_chunk.html#a73bba333ef4297011d61933caea5ebd3", null ],
       [ "MOVABLE_TYPE_NAME", "class_ogre_1_1_volume_1_1_chunk.html#af9976d39e8764f4b5743ce6ce0619162", null ]
     ] ],
-    [ "Ogre::Volume::ChunkHandler", "class_ogre_1_1_volume_1_1_chunk_handler.html", [
-      [ "ChunkHandler", "class_ogre_1_1_volume_1_1_chunk_handler.html#ab8efefa0d78d0ba30cab05bfea70a277", null ],
-      [ "~ChunkHandler", "class_ogre_1_1_volume_1_1_chunk_handler.html#a1517ea9c2dae541805fadab8cdda4f20", null ],
-      [ "addRequest", "class_ogre_1_1_volume_1_1_chunk_handler.html#a45aca5ac0738bf63b7539627a9d0d978", null ],
-      [ "processWorkQueue", "class_ogre_1_1_volume_1_1_chunk_handler.html#a01cc02bd48e1529f4ad464dc19f3e420", null ],
-      [ "handleRequest", "class_ogre_1_1_volume_1_1_chunk_handler.html#a2bb58c8f5cd6e9a59e743c3f1c5eeaeb", null ],
-      [ "handleResponse", "class_ogre_1_1_volume_1_1_chunk_handler.html#abfe457979450e735b65e5c53712f64c2", null ]
-    ] ],
     [ "Ogre::Volume::ChunkParameters", "struct_ogre_1_1_volume_1_1_chunk_parameters.html", [
       [ "ChunkParameters", "struct_ogre_1_1_volume_1_1_chunk_parameters.html#ad5118612e35d91011e06b9a97270e60f", null ],
       [ "sceneManager", "struct_ogre_1_1_volume_1_1_chunk_parameters.html#a3e154a179b8c824f79b1b426608743ad", null ],
@@ -54,17 +45,6 @@ var group___volume =
       [ "updateTo", "struct_ogre_1_1_volume_1_1_chunk_parameters.html#afe30999e8cc71a1f48d87d68bf43059d", null ],
       [ "async", "struct_ogre_1_1_volume_1_1_chunk_parameters.html#a6a296a1c6f91b7e50033d12bac67cb10", null ]
     ] ],
-    [ "Ogre::Volume::ChunkRequest", "struct_ogre_1_1_volume_1_1_chunk_request.html", [
-      [ "totalFrom", "struct_ogre_1_1_volume_1_1_chunk_request.html#a731afb5118648be0ea56bf4d025ff1b1", null ],
-      [ "totalTo", "struct_ogre_1_1_volume_1_1_chunk_request.html#a985f7346115226c2f0a1f8e81cdbb5af", null ],
-      [ "level", "struct_ogre_1_1_volume_1_1_chunk_request.html#ae5e6c6ee00b6c824bcc782266a440c42", null ],
-      [ "maxLevels", "struct_ogre_1_1_volume_1_1_chunk_request.html#a194b6f47569db10150aa2726d1ef0dd3", null ],
-      [ "meshBuilder", "struct_ogre_1_1_volume_1_1_chunk_request.html#ac010d5de8ae3bf620e523a64075f84f5", null ],
-      [ "dualGridGenerator", "struct_ogre_1_1_volume_1_1_chunk_request.html#aeaf3542ab1281572e1ecaea123aa66e1", null ],
-      [ "root", "struct_ogre_1_1_volume_1_1_chunk_request.html#a9350bd2d943fe62ca4ee0eb3f7b5c6ec", null ],
-      [ "origin", "struct_ogre_1_1_volume_1_1_chunk_request.html#a150c915275ff0b09d54e8f97afcbaffd", null ],
-      [ "isUpdate", "struct_ogre_1_1_volume_1_1_chunk_request.html#ab1953c58a16e1edfde6a843134cac2ff", null ]
-    ] ],
     [ "Ogre::Volume::ChunkTreeSharedData", "struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html", [
       [ "ChunkTreeSharedData", "struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html#abf3e0545802da294d9e24825b5c1413f", null ],
       [ "~ChunkTreeSharedData", "struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html#acf6fc07b8818eddc9299e4186bebce89", null ],
@@ -76,32 +56,32 @@ var group___volume =
     ] ],
     [ "Ogre::Volume::CSGCubeSource", "class_ogre_1_1_volume_1_1_c_s_g_cube_source.html", [
       [ "CSGCubeSource", "class_ogre_1_1_volume_1_1_c_s_g_cube_source.html#a909aaf010c97fa5ab71913a523e68199", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_cube_source.html#ac7a98fee047053b8d9295aa1fcb782ce", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_cube_source.html#afd9f39e86eb922cad95ee3e49718b5fe", null ]
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_cube_source.html#a6f712349245dddeb744b85e1ac2f5e24", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_cube_source.html#a87ac0a3b896e924dbbb3acdaecd869c2", null ]
     ] ],
     [ "Ogre::Volume::CSGDifferenceSource", "class_ogre_1_1_volume_1_1_c_s_g_difference_source.html", [
       [ "CSGDifferenceSource", "class_ogre_1_1_volume_1_1_c_s_g_difference_source.html#a949c5186291b3a81d859f68b2f90e8f4", null ],
       [ "CSGDifferenceSource", "class_ogre_1_1_volume_1_1_c_s_g_difference_source.html#a69ae962f2ac460ef277af87ded884db7", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_difference_source.html#acd7df698d869bfe95a34f53243b7e53a", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_difference_source.html#a16774feeaaf98908d19a22ba0d984ca2", null ]
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_difference_source.html#afa3debf4efb838f8fe9560763c852b86", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_difference_source.html#a1fc61442a537645c3951b66c8e630835", null ]
     ] ],
     [ "Ogre::Volume::CSGIntersectionSource", "class_ogre_1_1_volume_1_1_c_s_g_intersection_source.html", [
       [ "CSGIntersectionSource", "class_ogre_1_1_volume_1_1_c_s_g_intersection_source.html#a822ed0ba09261cffdcfbdaf21cc6fd27", null ],
       [ "CSGIntersectionSource", "class_ogre_1_1_volume_1_1_c_s_g_intersection_source.html#a9b7ea7003e925eb6ebcec143ff6ec96d", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_intersection_source.html#a22a365b89f9f101a96909e81ef3a2b8f", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_intersection_source.html#ab286fe8a82819d12dd8e416ca9ff30c5", null ]
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_intersection_source.html#a0d0884fe7c455b5286424da0071f4581", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_intersection_source.html#a4fdcb828f2c0d7b29bf75c0197d16520", null ]
     ] ],
     [ "Ogre::Volume::CSGNegateSource", "class_ogre_1_1_volume_1_1_c_s_g_negate_source.html", [
       [ "CSGNegateSource", "class_ogre_1_1_volume_1_1_c_s_g_negate_source.html#ad31af55109f8bb24ae4dda2cafd0a4d0", null ],
       [ "CSGNegateSource", "class_ogre_1_1_volume_1_1_c_s_g_negate_source.html#a9fcd1436e51d8f084b38e539a8f24a8c", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_negate_source.html#ac3a6a67403f36ace227e841a92d9b286", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_negate_source.html#a58ff8177c2d7f0096cda7a82e7db8129", null ]
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_negate_source.html#a92c029fd138ab80cbac975c4792eb017", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_negate_source.html#a5f1e20e3e00c2addb4b3b11c8fd62f5e", null ]
     ] ],
     [ "Ogre::Volume::CSGNoiseSource", "class_ogre_1_1_volume_1_1_c_s_g_noise_source.html", [
       [ "CSGNoiseSource", "class_ogre_1_1_volume_1_1_c_s_g_noise_source.html#acbaea2aa37b1e2094033f730bcf8d842", null ],
       [ "CSGNoiseSource", "class_ogre_1_1_volume_1_1_c_s_g_noise_source.html#acb6a51626a9f1c4bfdda885bd9c54b06", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_noise_source.html#aabd803488bc0d2fafb35071997cf973a", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_noise_source.html#a91708d6a3f01ea596996822a664faed4", null ],
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_noise_source.html#ae345927fa6a8f7a3b5668cc598c95b42", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_noise_source.html#a64205b50a8a405d8577b8a6869ef6583", null ],
       [ "getSeed", "class_ogre_1_1_volume_1_1_c_s_g_noise_source.html#a19c66b77e26768752590a3ae60cbd592", null ]
     ] ],
     [ "Ogre::Volume::CSGOperationSource", "class_ogre_1_1_volume_1_1_c_s_g_operation_source.html", [
@@ -112,18 +92,18 @@ var group___volume =
     ] ],
     [ "Ogre::Volume::CSGPlaneSource", "class_ogre_1_1_volume_1_1_c_s_g_plane_source.html", [
       [ "CSGPlaneSource", "class_ogre_1_1_volume_1_1_c_s_g_plane_source.html#a72e6ddc3d83574a122cfaeb6fec15a8f", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_plane_source.html#aedaa325385fc58df42cbed87f5b4a780", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_plane_source.html#ad10436c7343dff1873325fbc8e9437db", null ]
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_plane_source.html#a91e7400b407ef91a62a09b9801ccd1ad", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_plane_source.html#ac3b244d7cb136a303bbdebb14429646d", null ]
     ] ],
     [ "Ogre::Volume::CSGScaleSource", "class_ogre_1_1_volume_1_1_c_s_g_scale_source.html", [
       [ "CSGScaleSource", "class_ogre_1_1_volume_1_1_c_s_g_scale_source.html#a94f26a84a61b224e3836a8916df7153f", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_scale_source.html#a93d5ab2969fd76b6e401af33e120d031", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_scale_source.html#a8e3815f069c152ec4f628c83e396a739", null ]
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_scale_source.html#a4ab1cb67080d74aeddbce5de4528ea6a", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_scale_source.html#acf2c46521033b41d213c36616f5d0f99", null ]
     ] ],
     [ "Ogre::Volume::CSGSphereSource", "class_ogre_1_1_volume_1_1_c_s_g_sphere_source.html", [
       [ "CSGSphereSource", "class_ogre_1_1_volume_1_1_c_s_g_sphere_source.html#a175cd00ed506493006ba0a51be7cd334", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_sphere_source.html#af09c063c0ad5ca82f8ae6a30be75bca1", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_sphere_source.html#a8dbfa4912a79c02013a33f6098bff7ab", null ]
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_sphere_source.html#aa7656897c9690414dbcbb9d01ea6c124", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_sphere_source.html#a2b471d87caa4a711bff60d9b435f8732", null ]
     ] ],
     [ "Ogre::Volume::CSGUnarySource", "class_ogre_1_1_volume_1_1_c_s_g_unary_source.html", [
       [ "getSource", "class_ogre_1_1_volume_1_1_c_s_g_unary_source.html#a0324f86ebd17d5f269f22bcbc3f616a1", null ],
@@ -132,8 +112,8 @@ var group___volume =
     [ "Ogre::Volume::CSGUnionSource", "class_ogre_1_1_volume_1_1_c_s_g_union_source.html", [
       [ "CSGUnionSource", "class_ogre_1_1_volume_1_1_c_s_g_union_source.html#a6a7051ca43006e7ca82b14bcb5322c29", null ],
       [ "CSGUnionSource", "class_ogre_1_1_volume_1_1_c_s_g_union_source.html#a24304808fb8be804cbbcb0e8f3ef81f8", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_union_source.html#a93bb6dfa6c4cb8f291f2aa1ebfea9ba3", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_union_source.html#af3609e49469cbe280c635c0f6ba91598", null ]
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_c_s_g_union_source.html#ab1666aecb3402e7725e38b01d5fffcec", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_c_s_g_union_source.html#a3e2ac54f1442c334e4ef6711d668e9f8", null ]
     ] ],
     [ "Ogre::Volume::DualCell", "struct_ogre_1_1_volume_1_1_dual_cell.html", [
       [ "DualCell", "struct_ogre_1_1_volume_1_1_dual_cell.html#a3da89c366371d8f8f24c95307a897caf", null ],
@@ -156,8 +136,8 @@ var group___volume =
     [ "Ogre::Volume::GridSource", "class_ogre_1_1_volume_1_1_grid_source.html", [
       [ "GridSource", "class_ogre_1_1_volume_1_1_grid_source.html#a061baf427896c9a1fcf8152d03d4e8bd", null ],
       [ "~GridSource", "class_ogre_1_1_volume_1_1_grid_source.html#a8be67f783487a5b0d80b9c7833f765a6", null ],
-      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_grid_source.html#abd503727f50af4b458fd8d3c6af204c3", null ],
-      [ "getValue", "class_ogre_1_1_volume_1_1_grid_source.html#a53520582a00e496bf90aba5a21a254b6", null ],
+      [ "getValueAndGradient", "class_ogre_1_1_volume_1_1_grid_source.html#ac79c479b842f917d726b8dd6f09abb45", null ],
+      [ "getValue", "class_ogre_1_1_volume_1_1_grid_source.html#a2c4da445cfbbac7b37f1cddecdaac03c", null ],
       [ "getWidth", "class_ogre_1_1_volume_1_1_grid_source.html#ab7d2024e1888894bdea54596c26d7f38", null ],
       [ "getHeight", "class_ogre_1_1_volume_1_1_grid_source.html#ab55fbe3136da1e477521fe2314a5017b", null ],
       [ "getDepth", "class_ogre_1_1_volume_1_1_grid_source.html#a2b3f3066c875ee88c5c6217c840f79a6", null ],
@@ -183,8 +163,8 @@ var group___volume =
     ] ],
     [ "Ogre::Volume::IsoSurfaceMC", "class_ogre_1_1_volume_1_1_iso_surface_m_c.html", [
       [ "IsoSurfaceMC", "class_ogre_1_1_volume_1_1_iso_surface_m_c.html#aa9f22f872e92ebdcf19ca8d047cf4a67", null ],
-      [ "addMarchingCubesTriangles", "class_ogre_1_1_volume_1_1_iso_surface_m_c.html#a39db556a83891a0201330c748c80821c", null ],
-      [ "addMarchingSquaresTriangles", "class_ogre_1_1_volume_1_1_iso_surface_m_c.html#ae28ca071c68a271362ec9dc103f0a72c", null ]
+      [ "addMarchingCubesTriangles", "class_ogre_1_1_volume_1_1_iso_surface_m_c.html#ab0bb8088c01692db1d167b6766e72632", null ],
+      [ "addMarchingSquaresTriangles", "class_ogre_1_1_volume_1_1_iso_surface_m_c.html#ae13b5d3d102f3491fe4acd36d0c38275", null ]
     ] ],
     [ "Ogre::Volume::MeshBuilder", "class_ogre_1_1_volume_1_1_mesh_builder.html", [
       [ "MeshBuilder", "class_ogre_1_1_volume_1_1_mesh_builder.html#a21ee4b8440710f4e4015c1396347e674", null ],
@@ -286,7 +266,6 @@ var group___volume =
     ] ],
     [ "Ogre::Volume::ChunkParameters", "group___volume.html#ga8d688e0c7f69404eb6d8d716b75cc0ff", null ],
     [ "Ogre::Volume::ChunkTreeSharedData", "group___volume.html#ga9a2188f8dcb2d267f00eecf97bdd9425", null ],
-    [ "Ogre::Volume::ChunkRequest", "group___volume.html#ga67c04de7dae4381e03be17c2a498ff58", null ],
     [ "Ogre::Volume::DualCell", "group___volume.html#gaab8452656c1c65500c497e7fe0cc712c", null ],
     [ "Ogre::Volume::VecDualCell", "group___volume.html#gaba362e5d4ee54e19d9f7025c2a9c7e85", null ],
     [ "Ogre::Volume::Vertex", "group___volume.html#ga89f21806decd3e6441190d071eed6a5c", null ],
