@@ -1,5 +1,8 @@
 var NAVTREEINDEX1 =
 {
+"_ogre_animable_8h.html":[8,0,1,0,2],
+"_ogre_animation_8h.html":[8,0,1,0,3],
+"_ogre_animation_state_8h.html":[8,0,1,0,4],
 "_ogre_animation_track_8h.html":[8,0,1,0,5],
 "_ogre_anti_portal_8h.html":[8,0,2,10,1,0],
 "_ogre_any_8h.html":[8,0,1,0,6],
@@ -65,10 +68,11 @@ var NAVTREEINDEX1 =
 "_ogre_compositor_logic_8h.html":[8,0,1,0,30],
 "_ogre_compositor_manager_8h.html":[8,0,1,0,31],
 "_ogre_config_8h.html":[8,0,1,0,32],
-"_ogre_config_8h.html#a1555343fe7aade0966aa442f2e0c16f5":[8,0,1,0,32,5],
+"_ogre_config_8h.html#a1555343fe7aade0966aa442f2e0c16f5":[8,0,1,0,32,6],
 "_ogre_config_8h.html#a1c5fd80e6e0f2f85d6facbe1ec8eb5a4":[8,0,1,0,32,2],
 "_ogre_config_8h.html#a25da6395d80814d615a4db506aac2be0":[8,0,1,0,32,0],
 "_ogre_config_8h.html#a3d20e242d4a6aab7de105d85608b286a":[8,0,1,0,32,3],
+"_ogre_config_8h.html#a4393e2afffe021cb323b896779de3d17":[8,0,1,0,32,5],
 "_ogre_config_8h.html#a73f03c4000193e826a1489b02ea50309":[8,0,1,0,32,1],
 "_ogre_config_8h.html#aec70545291c5268ff4007e5516f09985":[8,0,1,0,32,4],
 "_ogre_config_dialog_8h.html":[8,0,1,0,33],
@@ -111,6 +115,7 @@ var NAVTREEINDEX1 =
 "_ogre_d3_d11_render_window_8h.html":[8,0,3,0,0,19],
 "_ogre_d3_d11_stereo_driver_a_m_d_8h.html":[8,0,3,0,0,20],
 "_ogre_d3_d11_stereo_driver_bridge_8h.html":[8,0,3,0,0,21],
+"_ogre_d3_d11_stereo_driver_bridge_8h.html#a0dc95acfbcfe7132927cf4afae836168":[8,0,3,0,0,21,1],
 "_ogre_d3_d11_stereo_driver_impl_8h.html":[8,0,3,0,0,22],
 "_ogre_d3_d11_stereo_driver_n_v_i_d_i_a_8h.html":[8,0,3,0,0,23],
 "_ogre_d3_d11_texture_8h.html":[8,0,3,0,0,24],
@@ -174,35 +179,36 @@ var NAVTREEINDEX1 =
 "_ogre_data_stream_8h.html#a71a2d398037a64aa241ef5c0be350430":[8,0,1,0,40,0],
 "_ogre_default_debug_drawer_8h.html":[8,0,1,0,41],
 "_ogre_default_hardware_buffer_manager_8h.html":[8,0,1,0,42],
+"_ogre_default_work_queue_8h.html":[8,0,1,0,43],
 "_ogre_default_zone_8h.html":[8,0,2,10,1,2],
-"_ogre_deflate_8h.html":[8,0,1,0,43],
-"_ogre_deflate_8h.html#a8697d4541486ef84a6eef760663668ac":[8,0,1,0,43,2],
+"_ogre_deflate_8h.html":[8,0,1,0,44],
+"_ogre_deflate_8h.html#a8697d4541486ef84a6eef760663668ac":[8,0,1,0,44,2],
 "_ogre_deflector_plane_affector_8h.html":[8,0,2,9,0,7],
-"_ogre_deprecated_8h.html":[8,0,1,0,44],
-"_ogre_depth_buffer_8h.html":[8,0,1,0,45],
+"_ogre_deprecated_8h.html":[8,0,1,0,45],
+"_ogre_depth_buffer_8h.html":[8,0,1,0,46],
 "_ogre_direction_randomiser_affector_8h.html":[8,0,2,9,0,8],
-"_ogre_distance_lod_strategy_8h.html":[8,0,1,0,46],
+"_ogre_distance_lod_strategy_8h.html":[8,0,1,0,47],
 "_ogre_dot_scene_loader_8h.html":[8,0,2,3,0,0],
-"_ogre_dual_quaternion_8h.html":[8,0,1,0,47],
-"_ogre_dyn_lib_8h.html":[8,0,1,0,48],
-"_ogre_dyn_lib_manager_8h.html":[8,0,1,0,49],
+"_ogre_dual_quaternion_8h.html":[8,0,1,0,48],
+"_ogre_dyn_lib_8h.html":[8,0,1,0,49],
+"_ogre_dyn_lib_manager_8h.html":[8,0,1,0,50],
 "_ogre_e_x_r_codec_8h.html":[8,0,2,4,0,0],
-"_ogre_edge_list_builder_8h.html":[8,0,1,0,50],
+"_ogre_edge_list_builder_8h.html":[8,0,1,0,51],
 "_ogre_ellipsoid_emitter_8h.html":[8,0,2,9,0,9],
-"_ogre_entity_8h.html":[8,0,1,0,51],
-"_ogre_exception_8h.html":[8,0,1,0,52],
-"_ogre_exception_8h.html#a3db118ef7a8ad7b905ac01266c56d03e":[8,0,1,0,52,1],
-"_ogre_exception_8h.html#ab64188d2d6f4a02714a8f02e23a491d2":[8,0,1,0,52,0],
-"_ogre_external_texture_source_8h.html":[8,0,1,0,53],
-"_ogre_external_texture_source_manager_8h.html":[8,0,1,0,54],
-"_ogre_factory_obj_8h.html":[8,0,1,0,55],
-"_ogre_file_system_8h.html":[8,0,1,0,56],
-"_ogre_file_system_layer_8h.html":[8,0,1,0,57],
+"_ogre_entity_8h.html":[8,0,1,0,52],
+"_ogre_exception_8h.html":[8,0,1,0,53],
+"_ogre_exception_8h.html#a3db118ef7a8ad7b905ac01266c56d03e":[8,0,1,0,53,1],
+"_ogre_exception_8h.html#ab64188d2d6f4a02714a8f02e23a491d2":[8,0,1,0,53,0],
+"_ogre_external_texture_source_8h.html":[8,0,1,0,54],
+"_ogre_external_texture_source_manager_8h.html":[8,0,1,0,55],
+"_ogre_factory_obj_8h.html":[8,0,1,0,56],
+"_ogre_file_system_8h.html":[8,0,1,0,57],
+"_ogre_file_system_layer_8h.html":[8,0,1,0,58],
 "_ogre_font_8h.html":[8,0,0,3,0,1],
 "_ogre_font_manager_8h.html":[8,0,0,3,0,2],
-"_ogre_frame_listener_8h.html":[8,0,1,0,58],
+"_ogre_frame_listener_8h.html":[8,0,1,0,59],
 "_ogre_free_image_codec_8h.html":[8,0,2,5,0,0],
-"_ogre_frustum_8h.html":[8,0,1,0,59],
+"_ogre_frustum_8h.html":[8,0,1,0,60],
 "_ogre_g_l3_plus_f_b_o_multi_render_target_8h.html":[8,0,3,3,0,0],
 "_ogre_g_l3_plus_f_b_o_render_texture_8h.html":[8,0,3,3,0,1],
 "_ogre_g_l3_plus_frame_buffer_object_8h.html":[8,0,3,3,0,2],
@@ -213,14 +219,13 @@ var NAVTREEINDEX1 =
 "_ogre_g_l3_plus_pixel_format_8h.html":[8,0,3,3,0,7],
 "_ogre_g_l3_plus_plugin_8h.html":[8,0,3,3,0,8],
 "_ogre_g_l3_plus_prerequisites_8h.html":[8,0,3,3,0,9],
-"_ogre_g_l3_plus_prerequisites_8h.html#a1d024823a1fd7f7db939205a9971c720":[8,0,3,3,0,9,6],
-"_ogre_g_l3_plus_prerequisites_8h.html#a68ed09c6ada21ef994461cea24497286":[8,0,3,3,0,9,3],
-"_ogre_g_l3_plus_prerequisites_8h.html#a7369271d1f22cf8cc723d617031b422e":[8,0,3,3,0,9,0],
-"_ogre_g_l3_plus_prerequisites_8h.html#a73ff6a326ebf3637a67218046668ce64":[8,0,3,3,0,9,2],
-"_ogre_g_l3_plus_prerequisites_8h.html#a968424fbd35a790c30cddcf272114e57":[8,0,3,3,0,9,7],
-"_ogre_g_l3_plus_prerequisites_8h.html#a9c15fe1e91b07ea3280f5239f9841b67":[8,0,3,3,0,9,1],
-"_ogre_g_l3_plus_prerequisites_8h.html#aafabbc5c59d9619538f8f0015434e8a0":[8,0,3,3,0,9,5],
-"_ogre_g_l3_plus_prerequisites_8h.html#acaa8c2a74138ea8c8d5834c5ab2ef40b":[8,0,3,3,0,9,4],
+"_ogre_g_l3_plus_prerequisites_8h.html#a1d024823a1fd7f7db939205a9971c720":[8,0,3,3,0,9,5],
+"_ogre_g_l3_plus_prerequisites_8h.html#a68ed09c6ada21ef994461cea24497286":[8,0,3,3,0,9,2],
+"_ogre_g_l3_plus_prerequisites_8h.html#a73ff6a326ebf3637a67218046668ce64":[8,0,3,3,0,9,1],
+"_ogre_g_l3_plus_prerequisites_8h.html#a968424fbd35a790c30cddcf272114e57":[8,0,3,3,0,9,6],
+"_ogre_g_l3_plus_prerequisites_8h.html#a9c15fe1e91b07ea3280f5239f9841b67":[8,0,3,3,0,9,0],
+"_ogre_g_l3_plus_prerequisites_8h.html#aafabbc5c59d9619538f8f0015434e8a0":[8,0,3,3,0,9,4],
+"_ogre_g_l3_plus_prerequisites_8h.html#acaa8c2a74138ea8c8d5834c5ab2ef40b":[8,0,3,3,0,9,3],
 "_ogre_g_l3_plus_render_system_8h.html":[8,0,3,3,0,10],
 "_ogre_g_l3_plus_render_to_vertex_buffer_8h.html":[8,0,3,3,0,11],
 "_ogre_g_l3_plus_state_cache_manager_8h.html":[8,0,3,3,0,12],
@@ -244,10 +249,5 @@ var NAVTREEINDEX1 =
 "_ogre_g_l_e_s2_managed_resource_8h.html#a2ba4ff6675c8ddf3dfd8dd8bbb7bd8b0":[8,0,3,4,0,7,2],
 "_ogre_g_l_e_s2_managed_resource_8h.html#aaeee13d907997e765c7f0b1df8f050fe":[8,0,3,4,0,7,0],
 "_ogre_g_l_e_s2_managed_resource_manager_8h.html":[8,0,3,4,0,8],
-"_ogre_g_l_e_s2_pixel_format_8h.html":[8,0,3,4,0,9],
-"_ogre_g_l_e_s2_plugin_8h.html":[8,0,3,4,0,10],
-"_ogre_g_l_e_s2_prerequisites_8h.html":[8,0,3,4,0,11],
-"_ogre_g_l_e_s2_prerequisites_8h.html#a2f3266484065a594ac6b1feaf8e15b8d":[8,0,3,4,0,11,7],
-"_ogre_g_l_e_s2_prerequisites_8h.html#a68504b609da6d777c9ede488a5193575":[8,0,3,4,0,11,3],
-"_ogre_g_l_e_s2_prerequisites_8h.html#a68ed09c6ada21ef994461cea24497286":[8,0,3,4,0,11,5]
+"_ogre_g_l_e_s2_pixel_format_8h.html":[8,0,3,4,0,9]
 };
