@@ -1,19 +1,5 @@
 var NAVTREEINDEX9 =
 {
-"class_ogre_1_1_border_renderable.html#aa7f6b2da6115e327f9743643beb255c1":[5,1,3,1,5],
-"class_ogre_1_1_border_renderable.html#ac63f4204d3733523975908ac00c4658a":[5,1,3,1,3],
-"class_ogre_1_1_border_renderable.html#afd2b5746059b2eefff07b0c223a5ab9d":[5,1,3,1,6],
-"class_ogre_1_1_border_renderable.html#aff78b58d992411bed6aa1670fdb4b871":[5,1,3,1,2],
-"class_ogre_1_1_box_emitter.html":[5,2,10,1],
-"class_ogre_1_1_box_emitter.html#a1f25e04b92fc761ef27a49bbddda3ce3":[5,2,10,1,0],
-"class_ogre_1_1_box_emitter.html#aa6533452068a94dff0a61df6fb89ae3b":[5,2,10,1,1],
-"class_ogre_1_1_bsp_intersection_scene_query.html":[5,2,1,0],
-"class_ogre_1_1_bsp_intersection_scene_query.html#a41f6ea17202f479bff9081bfbd69b758":[5,2,1,0,0],
-"class_ogre_1_1_bsp_intersection_scene_query.html#aeb15094d92857e8646f716432a152ca8":[5,2,1,0,1],
-"class_ogre_1_1_bsp_level.html":[5,2,1,1],
-"class_ogre_1_1_bsp_level.html#a0078f789dc5c7dfa8e909bfb5b7aa683":[5,2,1,1,8],
-"class_ogre_1_1_bsp_level.html#a058020fea4785609e67b628c479e35e2":[5,2,1,1,0],
-"class_ogre_1_1_bsp_level.html#a089acbec439a13c5e3a43007040e4fde":[5,2,1,1,13],
 "class_ogre_1_1_bsp_level.html#a0a39be276b7610046058c1e7bc90d435":[5,2,1,1,2],
 "class_ogre_1_1_bsp_level.html#a102468f7968aa187a2612b4504b896e4":[5,2,1,1,19],
 "class_ogre_1_1_bsp_level.html#a2262404327d01504ac157b1de7fc9c3f":[5,2,1,1,12],
@@ -56,95 +42,101 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_bsp_node.html#aeba6c3273ed4fdf07c3aea84c2df87ab":[5,2,1,2,22],
 "class_ogre_1_1_bsp_node.html#aec9a1bc496cd833f81869079741a122b":[5,2,1,2,14],
 "class_ogre_1_1_bsp_ray_scene_query.html":[5,2,1,3],
-"class_ogre_1_1_bsp_ray_scene_query.html#a0c98549a0b1e7db7d54c6bbfc4f46d8f":[5,2,1,3,2],
+"class_ogre_1_1_bsp_ray_scene_query.html#a0a7e638608a44ba0b50998b84029d324":[5,2,1,3,5],
+"class_ogre_1_1_bsp_ray_scene_query.html#a0b402c03852f58373e2f8224242e1f4d":[5,2,1,3,3],
+"class_ogre_1_1_bsp_ray_scene_query.html#a5887059ed82ee59e0e5f0ae149b244d8":[5,2,1,3,4],
 "class_ogre_1_1_bsp_ray_scene_query.html#ae28099aef7f983a042efde7e298295b9":[5,2,1,3,0],
+"class_ogre_1_1_bsp_ray_scene_query.html#ae7d9dcfa961dcaf756c5ac2b278413eb":[5,2,1,3,2],
 "class_ogre_1_1_bsp_ray_scene_query.html#af688336da3971472963b32e52b17d251":[5,2,1,3,1],
 "class_ogre_1_1_bsp_scene_manager.html":[5,2,1,4],
+"class_ogre_1_1_bsp_scene_manager.html#a00bede8ae97fbfd56ae9a173aabb70e3":[5,2,1,4,16],
+"class_ogre_1_1_bsp_scene_manager.html#a046c5bdaddb4c0595b6c79b10037f9e4":[5,2,1,4,11],
 "class_ogre_1_1_bsp_scene_manager.html#a0f8a152457053472843eebfb6ec1bc0f":[5,2,1,4,7],
-"class_ogre_1_1_bsp_scene_manager.html#a12cfc049e1d6c343f9ecd6a4546265b4":[5,2,1,4,4],
+"class_ogre_1_1_bsp_scene_manager.html#a12204c33556c1f3c22c5652b6aaafa1b":[5,2,1,4,8],
+"class_ogre_1_1_bsp_scene_manager.html#a14115743f2fd57a125e6e7fa485e622d":[5,2,1,4,3],
 "class_ogre_1_1_bsp_scene_manager.html#a201d0b4ed0ec67b8480092dee0a5184a":[5,2,1,4,9],
-"class_ogre_1_1_bsp_scene_manager.html#a26625c537529cba039d4e30424ac6cf2":[5,2,1,4,2],
 "class_ogre_1_1_bsp_scene_manager.html#a344a49c8ef3b09b290b2e14c2bfa500d":[5,2,1,4,10],
-"class_ogre_1_1_bsp_scene_manager.html#a35b475390db15397c62881e4951b9051":[5,2,1,4,11],
-"class_ogre_1_1_bsp_scene_manager.html#a4444e8e94c01206790db4bfad8c487ea":[5,2,1,4,3],
-"class_ogre_1_1_bsp_scene_manager.html#a565c9a52e0c139f0c9fc1aa5856c1658":[5,2,1,4,17],
-"class_ogre_1_1_bsp_scene_manager.html#a6fabed7f85f1ff62845a11c5c824ba18":[5,2,1,4,12],
+"class_ogre_1_1_bsp_scene_manager.html#a6efcddf31f81825c0092d0a60babda3b":[5,2,1,4,6],
+"class_ogre_1_1_bsp_scene_manager.html#a7d2c528a848b18c5c5296905737ee36c":[5,2,1,4,13],
 "class_ogre_1_1_bsp_scene_manager.html#a884ea1e2f8b90a149f03de7b822c2385":[5,2,1,4,15],
-"class_ogre_1_1_bsp_scene_manager.html#a91c52dc16409d813d917981aeaf5359b":[5,2,1,4,5],
-"class_ogre_1_1_bsp_scene_manager.html#a9746fa406d8edbf8a80f1afcf009584b":[5,2,1,4,6],
+"class_ogre_1_1_bsp_scene_manager.html#a99ebf10a5f443434fae8b3208f92d088":[5,2,1,4,17],
+"class_ogre_1_1_bsp_scene_manager.html#aa5ac0d95321d764e70c0fb18e55a4915":[5,2,1,4,5],
 "class_ogre_1_1_bsp_scene_manager.html#aa872f5ea2bedbeb7dd9cf1b25a110c35":[5,2,1,4,1],
 "class_ogre_1_1_bsp_scene_manager.html#ab3e178ca87404a0687e2523e756ff5fd":[5,2,1,4,0],
-"class_ogre_1_1_bsp_scene_manager.html#abcdea8bbb6c3fe84593322e794199821":[5,2,1,4,16],
-"class_ogre_1_1_bsp_scene_manager.html#ad20fc693dfce46a6d99b7c0d0aca9c27":[5,2,1,4,13],
+"class_ogre_1_1_bsp_scene_manager.html#ac2269aefac9958545213fa85a1183408":[5,2,1,4,4],
+"class_ogre_1_1_bsp_scene_manager.html#add4847839039e485bee409f229b48b40":[5,2,1,4,12],
+"class_ogre_1_1_bsp_scene_manager.html#aefb30f708df66332b50fa83d241b2305":[5,2,1,4,2],
 "class_ogre_1_1_bsp_scene_manager.html#af55b958c50f23943eca3132c8f154147":[5,2,1,4,14],
-"class_ogre_1_1_bsp_scene_manager.html#afbed035d6e010f7df4727b2ff76e0750":[5,2,1,4,8],
 "class_ogre_1_1_bsp_scene_manager_factory.html":[5,2,1,5],
-"class_ogre_1_1_bsp_scene_manager_factory.html#a00c4e589af4d4dabea98be3556c71382":[5,2,1,5,3],
-"class_ogre_1_1_bsp_scene_manager_factory.html#aa421b5002cc903659a31aedc16bfdb72":[5,2,1,5,2],
-"class_ogre_1_1_bsp_scene_manager_factory.html#ac3cfb57b3ddfcff9c72723d62df466e4":[5,2,1,5,0],
-"class_ogre_1_1_bsp_scene_manager_factory.html#ade95318da6085531e0ab86a2d7b6bcd9":[5,2,1,5,1],
-"class_ogre_1_1_bsp_scene_manager_plugin.html":[7,0,0,55],
-"class_ogre_1_1_bsp_scene_manager_plugin.html":[6,0,1,58],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#a108e4103ebe33caaed309d94fc377053":[7,0,0,55,0],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#a108e4103ebe33caaed309d94fc377053":[6,0,1,58,0],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#a4f304f5c47ece3a7e844dac9ff92ed40":[7,0,0,55,3],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#a4f304f5c47ece3a7e844dac9ff92ed40":[6,0,1,58,3],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#a606b81b8f9c5d022aa606c4a75b56a5c":[7,0,0,55,6],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#a606b81b8f9c5d022aa606c4a75b56a5c":[6,0,1,58,6],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#a7ec53fdce3eb20822e11b48f88007800":[7,0,0,55,1],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#a7ec53fdce3eb20822e11b48f88007800":[6,0,1,58,1],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#aa5ec47827d5bee7fad86ac190a6a07fd":[7,0,0,55,2],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#aa5ec47827d5bee7fad86ac190a6a07fd":[6,0,1,58,2],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#aaffd22b53362f16d243d170d625663b2":[7,0,0,55,5],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#aaffd22b53362f16d243d170d625663b2":[6,0,1,58,5],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#ad4ed3db160dbbb447ad84973cc45ca13":[6,0,1,58,4],
-"class_ogre_1_1_bsp_scene_manager_plugin.html#ad4ed3db160dbbb447ad84973cc45ca13":[7,0,0,55,4],
+"class_ogre_1_1_bsp_scene_manager_factory.html#a00c4e589af4d4dabea98be3556c71382":[5,2,1,5,2],
+"class_ogre_1_1_bsp_scene_manager_factory.html#a89483d387ff238f181ebb69e2c5b6e67":[5,2,1,5,1],
+"class_ogre_1_1_bsp_scene_manager_factory.html#a8d4635a141f5fb4a17ae0232d952f125":[5,2,1,5,0],
+"class_ogre_1_1_bsp_scene_manager_plugin.html":[7,0,0,51],
+"class_ogre_1_1_bsp_scene_manager_plugin.html":[6,0,1,54],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#a108e4103ebe33caaed309d94fc377053":[6,0,1,54,0],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#a108e4103ebe33caaed309d94fc377053":[7,0,0,51,0],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#a4885b87bf2bf6c814e00eb88c2a10203":[6,0,1,54,3],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#a4885b87bf2bf6c814e00eb88c2a10203":[7,0,0,51,3],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#a637179bfeaef0ddc57240c6e1a48c45f":[6,0,1,54,5],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#a637179bfeaef0ddc57240c6e1a48c45f":[7,0,0,51,5],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#a7ec53fdce3eb20822e11b48f88007800":[6,0,1,54,1],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#a7ec53fdce3eb20822e11b48f88007800":[7,0,0,51,1],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#a9ccec03b5571edca77e798d8b90ac283":[6,0,1,54,6],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#a9ccec03b5571edca77e798d8b90ac283":[7,0,0,51,6],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#aaf797f4127d4103eb34f0488590aa28d":[7,0,0,51,4],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#aaf797f4127d4103eb34f0488590aa28d":[6,0,1,54,4],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#acdec5f30a49a982895f90a60071c4f8e":[7,0,0,51,2],
+"class_ogre_1_1_bsp_scene_manager_plugin.html#acdec5f30a49a982895f90a60071c4f8e":[6,0,1,54,2],
 "class_ogre_1_1_bsp_scene_node.html":[5,2,1,6],
-"class_ogre_1_1_bsp_scene_node.html#a1ee88a2f5a1f7fe70c4ea39a245aa6a1":[5,2,1,6,2],
 "class_ogre_1_1_bsp_scene_node.html#a387df029179fce1955902d2b6cd3ae8b":[5,2,1,6,1],
 "class_ogre_1_1_bsp_scene_node.html#a3c9fc7c13d2a9a92130e1b595f74fe8d":[5,2,1,6,0],
-"class_ogre_1_1_bsp_scene_node.html#a888affced3515671eb916f6cca89c614":[5,2,1,6,4],
-"class_ogre_1_1_bsp_scene_node.html#ab63ee0b87970f654eadc3d43c59a8eb5":[5,2,1,6,3],
-"class_ogre_1_1_bsp_scene_node.html#aedb8690d7cd00a804a659eac1ee45060":[5,2,1,6,5],
-"class_ogre_1_1_bullet_1_1_debug_drawer.html":[5,1,1,1],
-"class_ogre_1_1_bullet_1_1_debug_drawer.html#a0d386191c978d369277073f2fcce25f0":[5,1,1,1,0],
-"class_ogre_1_1_bullet_1_1_debug_drawer.html#a199c9831c0ad9afa7cc8cdf3b49cee51":[5,1,1,1,5],
-"class_ogre_1_1_bullet_1_1_debug_drawer.html#a2343c4ac21f83340721eb3b66ed31e37":[5,1,1,1,1],
-"class_ogre_1_1_bullet_1_1_debug_drawer.html#a4c56cd7b0c5a2b0a368b106f17d5ad78":[5,1,1,1,6],
-"class_ogre_1_1_bullet_1_1_debug_drawer.html#a8649c2b19d43ac17e6d8a78e64d7acc0":[5,1,1,1,8],
-"class_ogre_1_1_bullet_1_1_debug_drawer.html#a8661d09b5e2d90892f9529833f223875":[5,1,1,1,7],
-"class_ogre_1_1_bullet_1_1_debug_drawer.html#a98495f23bb7985799a4ededef4d4aa24":[5,1,1,1,4],
-"class_ogre_1_1_bullet_1_1_debug_drawer.html#aaef96f1a7d35f9e4891b0d1cc49cc59d":[5,1,1,1,2],
-"class_ogre_1_1_bullet_1_1_debug_drawer.html#ab29d64d4a06efab61c599d8dec15b8bd":[5,1,1,1,3],
-"class_ogre_1_1_bullet_1_1_dynamics_world.html":[5,1,1,2],
-"class_ogre_1_1_bullet_1_1_dynamics_world.html#a350e9a135437edb7b11b0667eac0bd75":[5,1,1,2,5],
-"class_ogre_1_1_bullet_1_1_dynamics_world.html#a3ef0f4b137145278b7901ac79cebaac6":[5,1,1,2,4],
-"class_ogre_1_1_bullet_1_1_dynamics_world.html#a54d4cbf8c35c17149c7287ad4d05b88e":[5,1,1,2,2],
-"class_ogre_1_1_bullet_1_1_dynamics_world.html#a7e72c8cb32eff9d058447ea7198f65ef":[5,1,1,2,0],
-"class_ogre_1_1_bullet_1_1_dynamics_world.html#ac2d90be56bf89f88b796a91fc399bf0c":[5,1,1,2,1],
-"class_ogre_1_1_bullet_1_1_dynamics_world.html#afcafa5a4a6ba86014b0a1273d9584e25":[5,1,1,2,3],
-"class_ogre_1_1_bullet_1_1_rigid_body_state.html":[5,1,1,4],
-"class_ogre_1_1_bullet_1_1_rigid_body_state.html#a14a91eebbcdadfd643cc43bf8b58a696":[5,1,1,4,0],
-"class_ogre_1_1_bullet_1_1_rigid_body_state.html#a466350948eac59f0c60769f70a022f71":[5,1,1,4,1],
-"class_ogre_1_1_bullet_1_1_rigid_body_state.html#aa2f3f39bc55bd0626356e8106e5522df":[5,1,1,4,2],
-"class_ogre_1_1_c_preprocessor.html":[6,0,1,93],
-"class_ogre_1_1_c_preprocessor.html":[7,0,0,90],
-"class_ogre_1_1_c_preprocessor.html#a11441b8e0c3cab4a61e3392a102024a1":[6,0,1,93,5],
-"class_ogre_1_1_c_preprocessor.html#a11441b8e0c3cab4a61e3392a102024a1":[7,0,0,90,5],
-"class_ogre_1_1_c_preprocessor.html#a2b7c3b1a3208a27b36e87eee69464508":[6,0,1,93,1],
-"class_ogre_1_1_c_preprocessor.html#a2b7c3b1a3208a27b36e87eee69464508":[7,0,0,90,1],
-"class_ogre_1_1_c_preprocessor.html#a3026667d0f447d89bcac3fd8c6007a00":[6,0,1,93,2],
-"class_ogre_1_1_c_preprocessor.html#a3026667d0f447d89bcac3fd8c6007a00":[7,0,0,90,2],
-"class_ogre_1_1_c_preprocessor.html#a3849848c4223928aea432f66184d541e":[7,0,0,90,4],
-"class_ogre_1_1_c_preprocessor.html#a3849848c4223928aea432f66184d541e":[6,0,1,93,4],
-"class_ogre_1_1_c_preprocessor.html#a70001f3fef03cc20b5142e67702c3b3f":[7,0,0,90,0],
-"class_ogre_1_1_c_preprocessor.html#a70001f3fef03cc20b5142e67702c3b3f":[6,0,1,93,0],
-"class_ogre_1_1_c_preprocessor.html#a72bef4ac969ebf92c5870d165e46af6a":[7,0,0,90,3],
-"class_ogre_1_1_c_preprocessor.html#a72bef4ac969ebf92c5870d165e46af6a":[6,0,1,93,3],
-"class_ogre_1_1_c_preprocessor.html#ae5a6f539ddabca71928dd965f2211434":[7,0,0,90,6],
-"class_ogre_1_1_c_preprocessor.html#ae5a6f539ddabca71928dd965f2211434":[6,0,1,93,6],
+"class_ogre_1_1_bsp_scene_node.html#a5aaba5c4f0ca1c0d896d9b9a753d78b1":[5,2,1,6,5],
+"class_ogre_1_1_bsp_scene_node.html#a645083e5abba280774870d26518e48ba":[5,2,1,6,2],
+"class_ogre_1_1_bsp_scene_node.html#a7925beb519b3f99fd01ed813250ce95b":[5,2,1,6,4],
+"class_ogre_1_1_bsp_scene_node.html#ae01f2cdeee4fce08c95f2485fb3c5856":[5,2,1,6,3],
+"class_ogre_1_1_bullet_1_1_collision_world.html":[5,1,1,1],
+"class_ogre_1_1_bullet_1_1_collision_world.html#a1a0a90916e7a319c950c52c7f02bfc43":[5,1,1,1,0],
+"class_ogre_1_1_bullet_1_1_collision_world.html#a289c5df44c8ed32c6c519d57ad6a1b6f":[5,1,1,1,3],
+"class_ogre_1_1_bullet_1_1_collision_world.html#a440552b57ebd041ca89164053ed24f8b":[5,1,1,1,1],
+"class_ogre_1_1_bullet_1_1_collision_world.html#aa1b97dfab12428da4b447c0f3ae59967":[5,1,1,1,2],
+"class_ogre_1_1_bullet_1_1_debug_drawer.html":[5,1,1,2],
+"class_ogre_1_1_bullet_1_1_debug_drawer.html#a1c032bc832e3247dd4a3d049bede33aa":[5,1,1,2,8],
+"class_ogre_1_1_bullet_1_1_debug_drawer.html#a2343c4ac21f83340721eb3b66ed31e37":[5,1,1,2,1],
+"class_ogre_1_1_bullet_1_1_debug_drawer.html#a590e3e215f6c7f48788d13b0e0f5128a":[5,1,1,2,0],
+"class_ogre_1_1_bullet_1_1_debug_drawer.html#a5f6bb25ccd538328c252fe024226ec6d":[5,1,1,2,3],
+"class_ogre_1_1_bullet_1_1_debug_drawer.html#a8661d09b5e2d90892f9529833f223875":[5,1,1,2,7],
+"class_ogre_1_1_bullet_1_1_debug_drawer.html#a8f180e0d867b2e93170b95c19a653750":[5,1,1,2,6],
+"class_ogre_1_1_bullet_1_1_debug_drawer.html#a9e0ca870d917efc8e41939a0b566f7b2":[5,1,1,2,2],
+"class_ogre_1_1_bullet_1_1_debug_drawer.html#aa4ca360f3e9f386856d8d55941f30dc2":[5,1,1,2,5],
+"class_ogre_1_1_bullet_1_1_debug_drawer.html#ab907a155841980e8bc351f7a60b1ec11":[5,1,1,2,4],
+"class_ogre_1_1_bullet_1_1_dynamics_world.html":[5,1,1,3],
+"class_ogre_1_1_bullet_1_1_dynamics_world.html#a3ef0f4b137145278b7901ac79cebaac6":[5,1,1,3,3],
+"class_ogre_1_1_bullet_1_1_dynamics_world.html#a54d4cbf8c35c17149c7287ad4d05b88e":[5,1,1,3,1],
+"class_ogre_1_1_bullet_1_1_dynamics_world.html#a7e72c8cb32eff9d058447ea7198f65ef":[5,1,1,3,0],
+"class_ogre_1_1_bullet_1_1_dynamics_world.html#afcafa5a4a6ba86014b0a1273d9584e25":[5,1,1,3,2],
+"class_ogre_1_1_bullet_1_1_rigid_body_state.html":[5,1,1,5],
+"class_ogre_1_1_bullet_1_1_rigid_body_state.html#a14a91eebbcdadfd643cc43bf8b58a696":[5,1,1,5,0],
+"class_ogre_1_1_bullet_1_1_rigid_body_state.html#a466350948eac59f0c60769f70a022f71":[5,1,1,5,1],
+"class_ogre_1_1_bullet_1_1_rigid_body_state.html#aa2f3f39bc55bd0626356e8106e5522df":[5,1,1,5,2],
+"class_ogre_1_1_c_preprocessor.html":[6,0,1,89],
+"class_ogre_1_1_c_preprocessor.html":[7,0,0,86],
+"class_ogre_1_1_c_preprocessor.html#a11441b8e0c3cab4a61e3392a102024a1":[7,0,0,86,5],
+"class_ogre_1_1_c_preprocessor.html#a11441b8e0c3cab4a61e3392a102024a1":[6,0,1,89,5],
+"class_ogre_1_1_c_preprocessor.html#a2b7c3b1a3208a27b36e87eee69464508":[6,0,1,89,1],
+"class_ogre_1_1_c_preprocessor.html#a2b7c3b1a3208a27b36e87eee69464508":[7,0,0,86,1],
+"class_ogre_1_1_c_preprocessor.html#a3026667d0f447d89bcac3fd8c6007a00":[7,0,0,86,2],
+"class_ogre_1_1_c_preprocessor.html#a3026667d0f447d89bcac3fd8c6007a00":[6,0,1,89,2],
+"class_ogre_1_1_c_preprocessor.html#a3849848c4223928aea432f66184d541e":[7,0,0,86,4],
+"class_ogre_1_1_c_preprocessor.html#a3849848c4223928aea432f66184d541e":[6,0,1,89,4],
+"class_ogre_1_1_c_preprocessor.html#a70001f3fef03cc20b5142e67702c3b3f":[7,0,0,86,0],
+"class_ogre_1_1_c_preprocessor.html#a70001f3fef03cc20b5142e67702c3b3f":[6,0,1,89,0],
+"class_ogre_1_1_c_preprocessor.html#a72bef4ac969ebf92c5870d165e46af6a":[6,0,1,89,3],
+"class_ogre_1_1_c_preprocessor.html#a72bef4ac969ebf92c5870d165e46af6a":[7,0,0,86,3],
+"class_ogre_1_1_c_preprocessor.html#ae5a6f539ddabca71928dd965f2211434":[6,0,1,89,6],
+"class_ogre_1_1_c_preprocessor.html#ae5a6f539ddabca71928dd965f2211434":[7,0,0,86,6],
 "class_ogre_1_1_camera.html":[5,0,9,2],
 "class_ogre_1_1_camera.html#a00d4b6eb852e11325a4a237625c5de85":[5,0,9,2,52],
+"class_ogre_1_1_camera.html#a017777f13f04bb01d32203ce74c02c1c":[5,0,9,2,74],
 "class_ogre_1_1_camera.html#a01a051833c384dd02edc5b1bc1ab20b7":[5,0,9,2,5],
 "class_ogre_1_1_camera.html#a01ebdd4bb11758ff40c84797ccf73974":[5,0,9,2,46],
 "class_ogre_1_1_camera.html#a063daea70f27ee80b47a9441b8fa152a":[5,0,9,2,78],
@@ -158,17 +150,18 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_camera.html#a25b8d5149e24a68aa2071f941e8315b8":[5,0,9,2,17],
 "class_ogre_1_1_camera.html#a2876d0b5fd2f13af5a39ace745f6d039":[5,0,9,2,84],
 "class_ogre_1_1_camera.html#a2b6193430367c085dde103152a34cc5b":[5,0,9,2,14],
+"class_ogre_1_1_camera.html#a2e308ef3ce0afb4e715144a9b9460a13":[5,0,9,2,32],
 "class_ogre_1_1_camera.html#a30cd8360e8f1885f537f6185b621c406":[5,0,9,2,25],
 "class_ogre_1_1_camera.html#a311f3f06799fc4ba14a233406e25503f":[5,0,9,2,3],
+"class_ogre_1_1_camera.html#a317d01327cfaaee9fd2b8cdc93c68f57":[5,0,9,2,76],
 "class_ogre_1_1_camera.html#a3436778d5472fbb52b695278805456fb":[5,0,9,2,21],
-"class_ogre_1_1_camera.html#a35245b8ebc6b09a88ad9df2bb3362bec":[5,0,9,2,73],
+"class_ogre_1_1_camera.html#a37cd34e25032c16baf7cdd4d46f66511":[5,0,9,2,73],
 "class_ogre_1_1_camera.html#a401200010bd5c1441006f03564f74e22":[5,0,9,2,65],
 "class_ogre_1_1_camera.html#a40785781854c0ef26b7ee2ac064bd601":[5,0,9,2,48],
 "class_ogre_1_1_camera.html#a4225c2dfc17536d140579052816c7b76":[5,0,9,2,53],
 "class_ogre_1_1_camera.html#a45076b5160a9d575a56769ea357c3b16":[5,0,9,2,80],
 "class_ogre_1_1_camera.html#a4808eec2a7c9b8d56ad1961b6a46a2b8":[5,0,9,2,87],
 "class_ogre_1_1_camera.html#a49b7b8fe85de280b70c012f8416fab6e":[5,0,9,2,40],
-"class_ogre_1_1_camera.html#a4c46de40244c1c15f4019b2befd0862a":[5,0,9,2,32],
 "class_ogre_1_1_camera.html#a4d5b3cac0c09c3cc37e36a957dcc7797":[5,0,9,2,19],
 "class_ogre_1_1_camera.html#a4fe3e4231262486405e531f58ed96866":[5,0,9,2,38],
 "class_ogre_1_1_camera.html#a544d92ca3b916325f63b460e4de5b752":[5,0,9,2,12],
@@ -186,7 +179,6 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_camera.html#a6f6d4353cdb639a8a4a360e1aa33b01a":[5,0,9,2,62],
 "class_ogre_1_1_camera.html#a6fc2cf5ece7f9466a05066c2162e43d6":[5,0,9,2,69],
 "class_ogre_1_1_camera.html#a711a9fe25dcc9b5079774c4ab37bc1c3":[5,0,9,2,42],
-"class_ogre_1_1_camera.html#a71fff8dac8cbf9bd3911e49a484fa61c":[5,0,9,2,72],
 "class_ogre_1_1_camera.html#a75d99079b5c05d9d29cbb744a16f488e":[5,0,9,2,7],
 "class_ogre_1_1_camera.html#a762b8fd8f29ca9e6c2803fa3d135f6e4":[5,0,9,2,55],
 "class_ogre_1_1_camera.html#a7666cc73efeab787e0094ee992eb9fee":[5,0,9,2,11],
@@ -195,18 +187,20 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_camera.html#a7886967570a02d7f69bec6505a767714":[5,0,9,2,83],
 "class_ogre_1_1_camera.html#a7a0139964202017cee9b0271058a93b1":[5,0,9,2,36],
 "class_ogre_1_1_camera.html#a7c7f5608c85e1c38cdb89df51e9d8b11":[5,0,9,2,28],
+"class_ogre_1_1_camera.html#a7c9dda3421876161115dce5f72334d25":[5,0,9,2,75],
 "class_ogre_1_1_camera.html#a7d20c29bed9f63ea78ec43c8ae53669d":[5,0,9,2,6],
 "class_ogre_1_1_camera.html#a7d7d770f2cab977be0dae849d3244b3b":[5,0,9,2,15],
-"class_ogre_1_1_camera.html#a802fce8831c8969abb401fa0803d0fed":[5,0,9,2,74],
 "class_ogre_1_1_camera.html#a80979fa21757e1e142b3aac77592fff9":[5,0,9,2,60],
 "class_ogre_1_1_camera.html#a891066e82092d315699f7963268a5c16":[5,0,9,2,24],
+"class_ogre_1_1_camera.html#a93430aa0ec356bf75a0e2a8a0326f517":[5,0,9,2,33],
 "class_ogre_1_1_camera.html#a98881a30eb353a94e7bbb5e153c58fc5":[5,0,9,2,68],
 "class_ogre_1_1_camera.html#a9bebdfc39d402f17199eba03ac6442b8":[5,0,9,2,2],
 "class_ogre_1_1_camera.html#a9e595e0eff0ba31cfe23af82ec53a048":[5,0,9,2,41],
 "class_ogre_1_1_camera.html#a9e6fa5fa50737e7af640ea8165ecd1e3":[5,0,9,2,16],
+"class_ogre_1_1_camera.html#aa52bee58d2e9762627de103d2ebf5a45":[5,0,9,2,72],
 "class_ogre_1_1_camera.html#aa8ad036fb057cc7914a8c58018cb37a1":[5,0,9,2,49],
 "class_ogre_1_1_camera.html#aac250bb57c630543b8241bfc8eb8b88a":[5,0,9,2,67],
-"class_ogre_1_1_camera.html#aaffba261ed32dd57be93be76a2a528d8":[5,0,9,2,75],
+"class_ogre_1_1_camera.html#aac44658488645021258fe86cf954e526":[5,0,9,2,77],
 "class_ogre_1_1_camera.html#ab08e86e0c1e87d6ea7a65d177bb8fef3":[5,0,9,2,34],
 "class_ogre_1_1_camera.html#ab6b87536a32e04638eb73f70034e811d":[5,0,9,2,27],
 "class_ogre_1_1_camera.html#aba89daf9e8a8682547f35ac774a7e1f3":[5,0,9,2,26],
@@ -221,16 +215,13 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_camera.html#ae0ad15da476fdcbf67bc6e8a4378fc8f":[5,0,9,2,29],
 "class_ogre_1_1_camera.html#ae167537dd3f080dcbbaf31e7028de571":[5,0,9,2,54],
 "class_ogre_1_1_camera.html#ae7a14b95d7133f70a6c005095299bd72":[5,0,9,2,39],
-"class_ogre_1_1_camera.html#ae9135b8d42a96e2119ca141eed2323bc":[5,0,9,2,33],
 "class_ogre_1_1_camera.html#aea10ac162479ea92dfe24875ba9c6b13":[5,0,9,2,31],
 "class_ogre_1_1_camera.html#aea839ea1fe27ff60ed13096dcb7cc118":[5,0,9,2,63],
-"class_ogre_1_1_camera.html#aeba129508d2ec59dccbe11f559566735":[5,0,9,2,76],
 "class_ogre_1_1_camera.html#aec77b25198173f5f28601456632bfedf":[5,0,9,2,71],
 "class_ogre_1_1_camera.html#aee8574bec9a61eb59584b897f15ce1ff":[5,0,9,2,64],
 "class_ogre_1_1_camera.html#af0f02c8ac7e6dc46ae6cd8ee209abd8e":[5,0,9,2,82],
 "class_ogre_1_1_camera.html#af3c79df85771d892413739d2aeac379c":[5,0,9,2,58],
 "class_ogre_1_1_camera.html#af47a93c963e7e90d20cd20cc39d73025":[5,0,9,2,81],
-"class_ogre_1_1_camera.html#afbb366a0f8186c2cb85a744556fa5680":[5,0,9,2,77],
 "class_ogre_1_1_camera.html#afde9e80354228a484b102727bc4c48af":[5,0,9,2,13],
 "class_ogre_1_1_camera.html#afdef5a2d632790d7c72f14ff672d4f54":[5,0,9,2,61],
 "class_ogre_1_1_camera.html#afff2f8ad1ed1a1750f9daf4a96e3b23f":[5,0,9,2,88],
@@ -249,5 +240,14 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_capsule.html#aab9f2941bf16966267a284799bf2ba3b":[5,2,9,0,8],
 "class_ogre_1_1_capsule.html#aace6ae7d91d348fc57862b13dd5ab588":[5,2,9,0,5],
 "class_ogre_1_1_capsule.html#ac136bc82a1182d6e8fc28334301c9242":[5,2,9,0,6],
-"class_ogre_1_1_capsule.html#ac2a8d71fa6bc0e1ebca688908811a008":[5,2,9,0,3]
+"class_ogre_1_1_capsule.html#ac2a8d71fa6bc0e1ebca688908811a008":[5,2,9,0,3],
+"class_ogre_1_1_capsule.html#afc5e0517c27499734169232bd9a71eb4":[5,2,9,0,1],
+"class_ogre_1_1_cg_fx_script_loader.html":[5,2,2,0],
+"class_ogre_1_1_cg_fx_script_loader.html#a34a4360ac818d310349f452e54bc068e":[5,2,2,0,5],
+"class_ogre_1_1_cg_fx_script_loader.html#a3670a8d9b0c6b3f3f5bc125624ded6c5":[5,2,2,0,1],
+"class_ogre_1_1_cg_fx_script_loader.html#a5d28be49df81011003ab2d9cd85bf339":[5,2,2,0,2],
+"class_ogre_1_1_cg_fx_script_loader.html#a688ead3299fa3100ba829c621cf4c7d4":[5,2,2,0,6],
+"class_ogre_1_1_cg_fx_script_loader.html#a98069098656de219a8c9063482191d88":[5,2,2,0,3],
+"class_ogre_1_1_cg_fx_script_loader.html#ad49475d8c23dc210475cd8d65ace72a4":[5,2,2,0,0],
+"class_ogre_1_1_cg_fx_script_loader.html#ae62797dc5668bbb462141166f29c9889":[5,2,2,0,4]
 };
