@@ -71,35 +71,32 @@ var searchData=
   ['defaulthardwarebuffer_68',['DefaultHardwareBuffer',['../class_ogre_1_1_default_hardware_buffer.html',1,'Ogre']]],
   ['defaulthardwarebuffermanager_69',['DefaultHardwareBufferManager',['../class_ogre_1_1_default_hardware_buffer_manager.html',1,'Ogre']]],
   ['defaulthardwarebuffermanagerbase_70',['DefaultHardwareBufferManagerBase',['../class_ogre_1_1_default_hardware_buffer_manager_base.html',1,'Ogre']]],
-  ['defaulthardwareindexbuffer_71',['DefaultHardwareIndexBuffer',['../class_ogre_1_1_default_hardware_index_buffer.html',1,'Ogre']]],
-  ['defaulthardwarevertexbuffer_72',['DefaultHardwareVertexBuffer',['../class_ogre_1_1_default_hardware_vertex_buffer.html',1,'Ogre']]],
-  ['defaultintersectionscenequery_73',['DefaultIntersectionSceneQuery',['../class_ogre_1_1_default_intersection_scene_query.html',1,'Ogre']]],
-  ['defaultplaneboundedvolumelistscenequery_74',['DefaultPlaneBoundedVolumeListSceneQuery',['../class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html',1,'Ogre']]],
-  ['defaultrayscenequery_75',['DefaultRaySceneQuery',['../class_ogre_1_1_default_ray_scene_query.html',1,'Ogre']]],
-  ['defaultscenemanager_76',['DefaultSceneManager',['../class_ogre_1_1_default_scene_manager.html',1,'Ogre']]],
-  ['defaultscenemanagerfactory_77',['DefaultSceneManagerFactory',['../class_ogre_1_1_default_scene_manager_factory.html',1,'Ogre']]],
-  ['defaultshadowcamerasetup_78',['DefaultShadowCameraSetup',['../class_ogre_1_1_default_shadow_camera_setup.html',1,'Ogre']]],
-  ['defaultspherescenequery_79',['DefaultSphereSceneQuery',['../class_ogre_1_1_default_sphere_scene_query.html',1,'Ogre']]],
-  ['defaulttexturemanager_80',['DefaultTextureManager',['../class_ogre_1_1_default_texture_manager.html',1,'Ogre']]],
-  ['defaultworkqueuebase_81',['DefaultWorkQueueBase',['../class_ogre_1_1_default_work_queue_base.html',1,'Ogre']]],
-  ['defaultzone_82',['DefaultZone',['../class_ogre_1_1_default_zone.html',1,'Ogre']]],
-  ['defaultzonefactory_83',['DefaultZoneFactory',['../class_ogre_1_1_default_zone_factory.html',1,'Ogre']]],
-  ['deflatestream_84',['DeflateStream',['../class_ogre_1_1_deflate_stream.html',1,'Ogre']]],
-  ['deflectorplaneaffector_85',['DeflectorPlaneAffector',['../class_ogre_1_1_deflector_plane_affector.html',1,'Ogre']]],
-  ['degree_86',['Degree',['../class_ogre_1_1_degree.html',1,'Ogre']]],
-  ['depthbuffer_87',['DepthBuffer',['../class_ogre_1_1_depth_buffer.html',1,'Ogre']]],
-  ['deque_88',['deque',['../struct_ogre_1_1deque.html',1,'Ogre']]],
-  ['directionrandomiseraffector_89',['DirectionRandomiserAffector',['../class_ogre_1_1_direction_randomiser_affector.html',1,'Ogre']]],
-  ['distancelodboxstrategy_90',['DistanceLodBoxStrategy',['../class_ogre_1_1_distance_lod_box_strategy.html',1,'Ogre']]],
-  ['distancelodspherestrategy_91',['DistanceLodSphereStrategy',['../class_ogre_1_1_distance_lod_sphere_strategy.html',1,'Ogre']]],
-  ['distancelodstrategybase_92',['DistanceLodStrategyBase',['../class_ogre_1_1_distance_lod_strategy_base.html',1,'Ogre']]],
-  ['dotsceneloader_93',['DotSceneLoader',['../class_ogre_1_1_dot_scene_loader.html',1,'Ogre']]],
-  ['dotsceneplugin_94',['DotScenePlugin',['../class_ogre_1_1_dot_scene_plugin.html',1,'Ogre']]],
-  ['driverversion_95',['DriverVersion',['../struct_ogre_1_1_driver_version.html',1,'Ogre']]],
-  ['dualcell_96',['DualCell',['../struct_ogre_1_1_volume_1_1_dual_cell.html',1,'Ogre::Volume']]],
-  ['dualgridgenerator_97',['DualGridGenerator',['../class_ogre_1_1_volume_1_1_dual_grid_generator.html',1,'Ogre::Volume']]],
-  ['dualquaternion_98',['DualQuaternion',['../class_ogre_1_1_dual_quaternion.html',1,'Ogre']]],
-  ['dynamicsworld_99',['DynamicsWorld',['../class_ogre_1_1_bullet_1_1_dynamics_world.html',1,'Ogre::Bullet']]],
-  ['dynlib_100',['DynLib',['../class_ogre_1_1_dyn_lib.html',1,'Ogre']]],
-  ['dynlibmanager_101',['DynLibManager',['../class_ogre_1_1_dyn_lib_manager.html',1,'Ogre']]]
+  ['defaultintersectionscenequery_71',['DefaultIntersectionSceneQuery',['../class_ogre_1_1_default_intersection_scene_query.html',1,'Ogre']]],
+  ['defaultplaneboundedvolumelistscenequery_72',['DefaultPlaneBoundedVolumeListSceneQuery',['../class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html',1,'Ogre']]],
+  ['defaultrayscenequery_73',['DefaultRaySceneQuery',['../class_ogre_1_1_default_ray_scene_query.html',1,'Ogre']]],
+  ['defaultshadowcamerasetup_74',['DefaultShadowCameraSetup',['../class_ogre_1_1_default_shadow_camera_setup.html',1,'Ogre']]],
+  ['defaultspherescenequery_75',['DefaultSphereSceneQuery',['../class_ogre_1_1_default_sphere_scene_query.html',1,'Ogre']]],
+  ['defaulttexturemanager_76',['DefaultTextureManager',['../class_ogre_1_1_default_texture_manager.html',1,'Ogre']]],
+  ['defaultworkqueue_77',['DefaultWorkQueue',['../class_ogre_1_1_default_work_queue.html',1,'Ogre']]],
+  ['defaultworkqueuebase_78',['DefaultWorkQueueBase',['../class_ogre_1_1_default_work_queue_base.html',1,'Ogre']]],
+  ['defaultzone_79',['DefaultZone',['../class_ogre_1_1_default_zone.html',1,'Ogre']]],
+  ['defaultzonefactory_80',['DefaultZoneFactory',['../class_ogre_1_1_default_zone_factory.html',1,'Ogre']]],
+  ['deflatestream_81',['DeflateStream',['../class_ogre_1_1_deflate_stream.html',1,'Ogre']]],
+  ['deflectorplaneaffector_82',['DeflectorPlaneAffector',['../class_ogre_1_1_deflector_plane_affector.html',1,'Ogre']]],
+  ['degree_83',['Degree',['../class_ogre_1_1_degree.html',1,'Ogre']]],
+  ['depthbuffer_84',['DepthBuffer',['../class_ogre_1_1_depth_buffer.html',1,'Ogre']]],
+  ['deque_85',['deque',['../struct_ogre_1_1deque.html',1,'Ogre']]],
+  ['directionrandomiseraffector_86',['DirectionRandomiserAffector',['../class_ogre_1_1_direction_randomiser_affector.html',1,'Ogre']]],
+  ['distancelodboxstrategy_87',['DistanceLodBoxStrategy',['../class_ogre_1_1_distance_lod_box_strategy.html',1,'Ogre']]],
+  ['distancelodspherestrategy_88',['DistanceLodSphereStrategy',['../class_ogre_1_1_distance_lod_sphere_strategy.html',1,'Ogre']]],
+  ['distancelodstrategybase_89',['DistanceLodStrategyBase',['../class_ogre_1_1_distance_lod_strategy_base.html',1,'Ogre']]],
+  ['dotsceneloader_90',['DotSceneLoader',['../class_ogre_1_1_dot_scene_loader.html',1,'Ogre']]],
+  ['dotsceneplugin_91',['DotScenePlugin',['../class_ogre_1_1_dot_scene_plugin.html',1,'Ogre']]],
+  ['driverversion_92',['DriverVersion',['../struct_ogre_1_1_driver_version.html',1,'Ogre']]],
+  ['dualcell_93',['DualCell',['../struct_ogre_1_1_volume_1_1_dual_cell.html',1,'Ogre::Volume']]],
+  ['dualgridgenerator_94',['DualGridGenerator',['../class_ogre_1_1_volume_1_1_dual_grid_generator.html',1,'Ogre::Volume']]],
+  ['dualquaternion_95',['DualQuaternion',['../class_ogre_1_1_dual_quaternion.html',1,'Ogre']]],
+  ['dynamicsworld_96',['DynamicsWorld',['../class_ogre_1_1_bullet_1_1_dynamics_world.html',1,'Ogre::Bullet']]],
+  ['dynlib_97',['DynLib',['../class_ogre_1_1_dyn_lib.html',1,'Ogre']]],
+  ['dynlibmanager_98',['DynLibManager',['../class_ogre_1_1_dyn_lib_manager.html',1,'Ogre']]]
 ];
