@@ -4,6 +4,5 @@ var searchData=
   ['opmask_1',['OpMask',['../class_ogre_1_1_r_t_shader_1_1_operand.html#a775b1b466c9d9072e718c56eb9d8d9ad',1,'Ogre::RTShader::Operand']]],
   ['opsemantic_2',['OpSemantic',['../class_ogre_1_1_r_t_shader_1_1_operand.html#a50ab83cea566b55ad9c66d0d93ea7e7a',1,'Ogre::RTShader::Operand']]],
   ['optimisationlevel_3',['OptimisationLevel',['../class_ogre_1_1_d3_d9_h_l_s_l_program.html#a549748dee587b870ec40786d64888117',1,'Ogre::D3D9HLSLProgram']]],
-  ['organisationmode_4',['OrganisationMode',['../class_ogre_1_1_queued_renderable_collection.html#ab44ba16fe8e8c0247234d4e6edfae844',1,'Ogre::QueuedRenderableCollection']]],
-  ['orientationmode_5',['OrientationMode',['../group___scene.html#ga492c508d79ebaeb2cbe0111f56d782a8',1,'Ogre']]]
+  ['organisationmode_4',['OrganisationMode',['../class_ogre_1_1_queued_renderable_collection.html#ab44ba16fe8e8c0247234d4e6edfae844',1,'Ogre::QueuedRenderableCollection']]]
 ];
