@@ -1,5 +1,5 @@
 var searchData=
 [
   ['instancing_2emd_0',['instancing.md',['../instancing_8md.html',1,'']]],
-  ['ogremetalview_2eh_1',['OgreMetalView.h',['../i_o_s_2_ogre_metal_view_8h.html',1,'']]]
+  ['ios_2fogremetalview_2eh_1',['OgreMetalView.h',['../i_o_s_2_ogre_metal_view_8h.html',1,'']]]
 ];
