@@ -1,6 +1,6 @@
 var indexSectionsWithContent =
 {
-  0: "_abcdefghijklmnopqrstuvwxyz~",
+  0: "012_abcdefghijklmnopqrstuvwxyz~’",
   1: "abcdefghiklmnopqrstuvwz",
   2: "aops",
   3: "abdehimnoprstv",
@@ -11,9 +11,9 @@ var indexSectionsWithContent =
   8: "_abcdefghijklmnopqrstuvwz",
   9: "cdlnps",
   10: "ago",
-  11: "_abcdeghmnorsw",
+  11: "_abcdeghmnorsvw",
   12: "abcdefgilmoprstv",
-  13: "abcdefghilmoprstuvwy"
+  13: "abcdefghilmnoprstuvwy"
 };
 
 var indexSectionNames =
