@@ -2,7 +2,7 @@ var searchData=
 [
   ['safebooltype_0',['SafeBoolType',['../class_ogre_1_1_com_ptr.html#a1cb5413c581370dfaf0dde6313d7ef40',1,'Ogre::ComPtr']]],
   ['samplerptr_1',['SamplerPtr',['../group___materials.html#ga34843c20652d796e4e3aab70dc1786c3',1,'Ogre']]],
-  ['scenemanageriterator_2',['SceneManagerIterator',['../class_ogre_1_1_scene_manager_enumerator.html#ad27d358bd89b7b44a8b360ce36df3aaa',1,'Ogre::SceneManagerEnumerator']]],
+  ['scenemanagerinstancemap_2',['SceneManagerInstanceMap',['../group___general.html#ga2803ea42ba6f7bc246ad3d2c92d2bdd0',1,'Ogre']]],
   ['scenenodelist_3',['SceneNodeList',['../group___p_c_z_scene_manager.html#ga05a24252386d9f480caf077f1d3917ef',1,'Ogre']]],
   ['scenequerymovableintersectionlist_4',['SceneQueryMovableIntersectionList',['../group___scene.html#gaaa1601dd915ea1b91530e88825dbfd2b',1,'Ogre']]],
   ['scenequerymovableobjectpair_5',['SceneQueryMovableObjectPair',['../group___scene.html#gaa1ca4f17a1e8bb7381446ae6235869d8',1,'Ogre']]],
@@ -28,33 +28,35 @@ var searchData=
   ['shaderparameterlist_25',['ShaderParameterList',['../namespace_ogre_1_1_r_t_shader.html#a560b1affa709492f1d2b37bdd94fde28',1,'Ogre::RTShader']]],
   ['shaderprofiles_26',['ShaderProfiles',['../class_ogre_1_1_render_system_capabilities.html#a44a272cf319952bf421faa15a473dd24',1,'Ogre::RenderSystemCapabilities']]],
   ['shadowcamerasetupptr_27',['ShadowCameraSetupPtr',['../namespace_ogre.html#a139829f6abc3581ec63563543ebfff15',1,'Ogre']]],
-  ['shadowrenderablelist_28',['ShadowRenderableList',['../group___scene.html#ga9cede0c48ca25a99ac76292fc2b05dc8',1,'Ogre::ShadowRenderableList()'],['../class_ogre_1_1_shadow_caster.html#a5987ad3b30d90f38c0a75fa763b0f649',1,'Ogre::ShadowCaster::ShadowRenderableList()']]],
+  ['shadowrenderablelist_28',['ShadowRenderableList',['../class_ogre_1_1_shadow_caster.html#a5987ad3b30d90f38c0a75fa763b0f649',1,'Ogre::ShadowCaster::ShadowRenderableList'],['../group___scene.html#ga9cede0c48ca25a99ac76292fc2b05dc8',1,'Ogre::ShadowRenderableList']]],
   ['shadowrenderablelistiterator_29',['ShadowRenderableListIterator',['../class_ogre_1_1_shadow_caster.html#a7b0999d33e25db97d0449d6cf95cbecd',1,'Ogre::ShadowCaster']]],
   ['shadowtextureconfiglist_30',['ShadowTextureConfigList',['../group___scene.html#ga498ca415d30ec282949ce7dce9d1db69',1,'Ogre']]],
   ['shadowtexturelist_31',['ShadowTextureList',['../group___scene.html#gab5efceec9e1a6e88e156564c15e86f6a',1,'Ogre']]],
   ['sharedparametersmap_32',['SharedParametersMap',['../class_ogre_1_1_gpu_program_manager.html#a2f14bd2002eb4be4b1d5ce5fb68fa505',1,'Ogre::GpuProgramManager']]],
-  ['size_5ftype_33',['size_type',['../class_ogre_1_1_small_vector_template_common.html#a8985bda74ea85da34c90a7356586e0c4',1,'Ogre::SmallVectorTemplateCommon::size_type()'],['../class_ogre_1_1_hashed_vector.html#af0b04cbf9823c57128855d112f3581e4',1,'Ogre::HashedVector::size_type()'],['../class_ogre_1_1_small_vector_impl.html#a07042d1d8ec08f3055174fc0f386b7ab',1,'Ogre::SmallVectorImpl::size_type()']]],
+  ['size_5ftype_33',['size_type',['../class_ogre_1_1_small_vector_template_common.html#a8985bda74ea85da34c90a7356586e0c4',1,'Ogre::SmallVectorTemplateCommon::size_type'],['../class_ogre_1_1_small_vector_impl.html#a07042d1d8ec08f3055174fc0f386b7ab',1,'Ogre::SmallVectorImpl::size_type']]],
   ['skeletonptr_34',['SkeletonPtr',['../namespace_ogre.html#a4ea60aa36ac918eee430bd614be9d018',1,'Ogre']]],
-  ['splitpointlist_35',['SplitPointList',['../class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#a8883a70f9fd1d0ed31bab5ce82f62b02',1,'Ogre::PSSMShadowCameraSetup::SplitPointList()'],['../class_ogre_1_1_r_t_shader_1_1_integrated_p_s_s_m3.html#a76f8d7a9424f079ae447aca32993ee45',1,'Ogre::RTShader::IntegratedPSSM3::SplitPointList()']]],
+  ['splitpointlist_35',['SplitPointList',['../class_ogre_1_1_p_s_s_m_shadow_camera_setup.html#a8883a70f9fd1d0ed31bab5ce82f62b02',1,'Ogre::PSSMShadowCameraSetup']]],
   ['statecachealloc_36',['StateCacheAlloc',['../namespace_ogre.html#a32224c5b6ceb3ec360ebf5b02398ec32',1,'Ogre']]],
-  ['strategymap_37',['StrategyMap',['../class_ogre_1_1_page_manager.html#a6bc619f289f2ed3491a822ee4abbbd3d',1,'Ogre::PageManager']]],
-  ['string_38',['String',['../namespace_ogre.html#aaf6cdc855bf9ae5edbf48a7e7dcb27f8',1,'Ogre']]],
-  ['stringstream_39',['StringStream',['../namespace_ogre.html#af9b3423b7c29049c4cfa637d4a41a28f',1,'Ogre']]],
-  ['stringvector_40',['StringVector',['../group___general.html#ga783e5227595f351519627abfb740ec85',1,'Ogre']]],
-  ['stringvectorptr_41',['StringVectorPtr',['../group___general.html#gae6b84ceebcdcc285f37bf9fba216697d',1,'Ogre']]],
-  ['strstreamtype_42',['StrStreamType',['../class_ogre_1_1_string_util.html#a665d79932d54b48b83acff563de7a9e5',1,'Ogre::StringUtil']]],
-  ['subentitylist_43',['SubEntityList',['../class_ogre_1_1_entity.html#abf738e5449c79b27c9a4863a32002d7e',1,'Ogre::Entity']]],
-  ['submeshgeometrylookup_44',['SubMeshGeometryLookup',['../class_ogre_1_1_static_geometry.html#a80c5f8105181b3e77468a87e5351825b',1,'Ogre::StaticGeometry']]],
-  ['submeshiterator_45',['SubMeshIterator',['../class_ogre_1_1_mesh.html#ac3955099a61b444cb9a2e7e111a1f271',1,'Ogre::Mesh']]],
-  ['submeshlist_46',['SubMeshList',['../class_ogre_1_1_mesh.html#aadf4f5fb8b74f46ca0fe5dfb530a5f64',1,'Ogre::Mesh']]],
-  ['submeshlodgeometrylinklist_47',['SubMeshLodGeometryLinkList',['../class_ogre_1_1_static_geometry.html#a9a3a337c0d120c4c3bf65850c25b103a',1,'Ogre::StaticGeometry']]],
-  ['submeshnamemap_48',['SubMeshNameMap',['../class_ogre_1_1_mesh.html#a65db044c9760efd26f839025ebfa7a98',1,'Ogre::Mesh']]],
-  ['subrenderstateaccessorptr_49',['SubRenderStateAccessorPtr',['../group___r_t_shader.html#gaecbe3817ee5b43f1962309c03d39da99',1,'Ogre::RTShader']]],
-  ['subrenderstatelist_50',['SubRenderStateList',['../group___r_t_shader.html#ga4baf7a0833de141d1d8b8115c75c4794',1,'Ogre::RTShader']]],
-  ['subrenderstatelistconstiterator_51',['SubRenderStateListConstIterator',['../group___r_t_shader.html#ga77f0abdb5d584c610fa03cf238295898',1,'Ogre::RTShader']]],
-  ['subrenderstatelistiterator_52',['SubRenderStateListIterator',['../group___r_t_shader.html#ga95497cc30a987c52f4159875824faa54',1,'Ogre::RTShader']]],
-  ['subrenderstateset_53',['SubRenderStateSet',['../group___r_t_shader.html#ga9b918e7e9259b2d82e48e788da9f1485',1,'Ogre::RTShader']]],
-  ['subrenderstatesetconstiterator_54',['SubRenderStateSetConstIterator',['../group___r_t_shader.html#ga00d3d84afe3e5e75ca3fe1050c2fd29a',1,'Ogre::RTShader']]],
-  ['subrenderstatesetiterator_55',['SubRenderStateSetIterator',['../group___r_t_shader.html#gab67a8756fb7f065af7052ef1fb14b1ec',1,'Ogre::RTShader']]],
-  ['syntaxcodes_56',['SyntaxCodes',['../class_ogre_1_1_gpu_program_manager.html#abc416b46732467b3b90cfd1332adb57e',1,'Ogre::GpuProgramManager']]]
+  ['staticgeometrymap_37',['StaticGeometryMap',['../class_ogre_1_1_scene_manager.html#a0cd89dcbd8d830a2a3c03dac27f42c44',1,'Ogre::SceneManager']]],
+  ['stereomodetype_38',['StereoModeType',['../namespace_ogre.html#a0dc95acfbcfe7132927cf4afae836168',1,'Ogre']]],
+  ['strategymap_39',['StrategyMap',['../class_ogre_1_1_page_manager.html#a6bc619f289f2ed3491a822ee4abbbd3d',1,'Ogre::PageManager']]],
+  ['string_40',['String',['../namespace_ogre.html#aaf6cdc855bf9ae5edbf48a7e7dcb27f8',1,'Ogre']]],
+  ['stringstream_41',['StringStream',['../namespace_ogre.html#af9b3423b7c29049c4cfa637d4a41a28f',1,'Ogre']]],
+  ['stringvector_42',['StringVector',['../group___general.html#ga783e5227595f351519627abfb740ec85',1,'Ogre']]],
+  ['stringvectorptr_43',['StringVectorPtr',['../group___general.html#gae6b84ceebcdcc285f37bf9fba216697d',1,'Ogre']]],
+  ['strstreamtype_44',['StrStreamType',['../class_ogre_1_1_string_util.html#a665d79932d54b48b83acff563de7a9e5',1,'Ogre::StringUtil']]],
+  ['subentitylist_45',['SubEntityList',['../class_ogre_1_1_entity.html#abf738e5449c79b27c9a4863a32002d7e',1,'Ogre::Entity']]],
+  ['submeshgeometrylookup_46',['SubMeshGeometryLookup',['../class_ogre_1_1_static_geometry.html#a80c5f8105181b3e77468a87e5351825b',1,'Ogre::StaticGeometry']]],
+  ['submeshiterator_47',['SubMeshIterator',['../class_ogre_1_1_mesh.html#ac3955099a61b444cb9a2e7e111a1f271',1,'Ogre::Mesh']]],
+  ['submeshlist_48',['SubMeshList',['../class_ogre_1_1_mesh.html#aadf4f5fb8b74f46ca0fe5dfb530a5f64',1,'Ogre::Mesh']]],
+  ['submeshlodgeometrylinklist_49',['SubMeshLodGeometryLinkList',['../class_ogre_1_1_static_geometry.html#a9a3a337c0d120c4c3bf65850c25b103a',1,'Ogre::StaticGeometry']]],
+  ['submeshnamemap_50',['SubMeshNameMap',['../class_ogre_1_1_mesh.html#a65db044c9760efd26f839025ebfa7a98',1,'Ogre::Mesh']]],
+  ['subrenderstateaccessorptr_51',['SubRenderStateAccessorPtr',['../group___r_t_shader.html#gaecbe3817ee5b43f1962309c03d39da99',1,'Ogre::RTShader']]],
+  ['subrenderstatelist_52',['SubRenderStateList',['../group___r_t_shader.html#ga4baf7a0833de141d1d8b8115c75c4794',1,'Ogre::RTShader']]],
+  ['subrenderstatelistconstiterator_53',['SubRenderStateListConstIterator',['../group___r_t_shader.html#ga77f0abdb5d584c610fa03cf238295898',1,'Ogre::RTShader']]],
+  ['subrenderstatelistiterator_54',['SubRenderStateListIterator',['../group___r_t_shader.html#ga95497cc30a987c52f4159875824faa54',1,'Ogre::RTShader']]],
+  ['subrenderstateset_55',['SubRenderStateSet',['../group___r_t_shader.html#ga9b918e7e9259b2d82e48e788da9f1485',1,'Ogre::RTShader']]],
+  ['subrenderstatesetconstiterator_56',['SubRenderStateSetConstIterator',['../group___r_t_shader.html#ga00d3d84afe3e5e75ca3fe1050c2fd29a',1,'Ogre::RTShader']]],
+  ['subrenderstatesetiterator_57',['SubRenderStateSetIterator',['../group___r_t_shader.html#gab67a8756fb7f065af7052ef1fb14b1ec',1,'Ogre::RTShader']]],
+  ['syntaxcodes_58',['SyntaxCodes',['../class_ogre_1_1_gpu_program_manager.html#abc416b46732467b3b90cfd1332adb57e',1,'Ogre::GpuProgramManager']]]
 ];
