@@ -11,13 +11,12 @@ var searchData=
   ['d3d9textureptr_8',['D3D9TexturePtr',['../namespace_ogre.html#a6988e5e5e5357fa0cfe879b9930fbb6a',1,'Ogre']]],
   ['datastreamlist_9',['DataStreamList',['../group___resources.html#ga346c957ca4b71d80a4124c63542a9cd6',1,'Ogre']]],
   ['datastreamptr_10',['DataStreamPtr',['../namespace_ogre.html#a8a2a961b4205aacff9c01e81e08d7781',1,'Ogre']]],
-  ['decoderesult_11',['DecodeResult',['../class_ogre_1_1_image_codec.html#a5de6ad1dfcdb1da1bdc36f4118b0fae7',1,'Ogre::ImageCodec']]],
-  ['decryptembeddedzipfilefunc_12',['DecryptEmbeddedZipFileFunc',['../class_ogre_1_1_embedded_zip_archive_factory.html#a9ef899ac1ebf7ab54f115c8ced9ff433',1,'Ogre::EmbeddedZipArchiveFactory']]],
-  ['defaulthardwareuniformbuffer_13',['DefaultHardwareUniformBuffer',['../group___render_system.html#gae48abb71a1e46f4cc3a188a603fa537d',1,'Ogre']]],
-  ['depthbuffermap_14',['DepthBufferMap',['../group___render_system.html#ga3398714c41b8c70059d8488a7b42ad3e',1,'Ogre']]],
-  ['depthbuffervec_15',['DepthBufferVec',['../group___render_system.html#ga439edbcaf99f14e7c60bd389b0411d2c',1,'Ogre']]],
-  ['difference_5ftype_16',['difference_type',['../class_ogre_1_1_small_vector_template_common.html#a60eb6558693ab2020fba03c8ea5038c5',1,'Ogre::SmallVectorTemplateCommon::difference_type()'],['../class_ogre_1_1_hashed_vector.html#a576ba91ab5ef4d1623fb71d1925518b4',1,'Ogre::HashedVector::difference_type()']]],
-  ['displaystring_17',['DisplayString',['../group___overlays.html#ga12ec415f18ba8932c5e0bfa49036fc5b',1,'Ogre']]],
-  ['dualcell_18',['DualCell',['../group___volume.html#gaab8452656c1c65500c497e7fe0cc712c',1,'Ogre::Volume']]],
-  ['dynlib_5fhandle_19',['DYNLIB_HANDLE',['../group___general.html#ga296be3af46168570d9f4bc5f3ef1e246',1,'Ogre']]]
+  ['decryptembeddedzipfilefunc_11',['DecryptEmbeddedZipFileFunc',['../class_ogre_1_1_embedded_zip_archive_factory.html#a9ef899ac1ebf7ab54f115c8ced9ff433',1,'Ogre::EmbeddedZipArchiveFactory']]],
+  ['defaulthardwareuniformbuffer_12',['DefaultHardwareUniformBuffer',['../group___render_system.html#gae48abb71a1e46f4cc3a188a603fa537d',1,'Ogre']]],
+  ['depthbuffermap_13',['DepthBufferMap',['../group___render_system.html#ga3398714c41b8c70059d8488a7b42ad3e',1,'Ogre']]],
+  ['depthbuffervec_14',['DepthBufferVec',['../group___render_system.html#ga439edbcaf99f14e7c60bd389b0411d2c',1,'Ogre']]],
+  ['difference_5ftype_15',['difference_type',['../class_ogre_1_1_small_vector_template_common.html#a60eb6558693ab2020fba03c8ea5038c5',1,'Ogre::SmallVectorTemplateCommon']]],
+  ['displaystring_16',['DisplayString',['../group___overlays.html#ga12ec415f18ba8932c5e0bfa49036fc5b',1,'Ogre']]],
+  ['dualcell_17',['DualCell',['../group___volume.html#gaab8452656c1c65500c497e7fe0cc712c',1,'Ogre::Volume']]],
+  ['dynlib_5fhandle_18',['DYNLIB_HANDLE',['../group___general.html#ga296be3af46168570d9f4bc5f3ef1e246',1,'Ogre']]]
 ];
