@@ -4,9 +4,9 @@ var searchData=
   ['uncompressedsize_1',['uncompressedSize',['../struct_ogre_1_1_file_info.html#a66c7bf4f59feb619016a5c70e4ded4ee',1,'Ogre::FileInfo']]],
   ['uniform_5findex_5fstart_2',['UNIFORM_INDEX_START',['../class_ogre_1_1_metal_program.html#a82c3f50c5cf71f6f6ed13c89fc66afa3',1,'Ogre::MetalProgram']]],
   ['uninitialized_5fcollapse_5fcost_3',['UNINITIALIZED_COLLAPSE_COST',['../struct_ogre_1_1_lod_data.html#af95ac40c4f3bdd402aa2e0cc1e25fc9c',1,'Ogre::LodData']]],
-  ['unit_5fscale_4',['UNIT_SCALE',['../struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a979837f10b7068528efc6802742f5509',1,'Ogre::VectorBase&lt; 2, Real &gt;::UNIT_SCALE()'],['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a89fbc371d11d0363db247d6ef1fa7afa',1,'Ogre::VectorBase&lt; 3, Real &gt;::UNIT_SCALE()']]],
-  ['unit_5fx_5',['UNIT_X',['../struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#adeeb454e50949d89f71b52a38e52951e',1,'Ogre::VectorBase&lt; 2, Real &gt;::UNIT_X()'],['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2fe25096ba980b3569e44833ddf155e6',1,'Ogre::VectorBase&lt; 3, Real &gt;::UNIT_X()']]],
-  ['unit_5fy_6',['UNIT_Y',['../struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ab771b243b99665aaff02505c273be9ee',1,'Ogre::VectorBase&lt; 2, Real &gt;::UNIT_Y()'],['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a25a0d767f153bc408453ee85de866c87',1,'Ogre::VectorBase&lt; 3, Real &gt;::UNIT_Y()']]],
+  ['unit_5fscale_4',['UNIT_SCALE',['../struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a979837f10b7068528efc6802742f5509',1,'Ogre::VectorBase&lt; 2, Real &gt;::UNIT_SCALE'],['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a89fbc371d11d0363db247d6ef1fa7afa',1,'Ogre::VectorBase&lt; 3, Real &gt;::UNIT_SCALE']]],
+  ['unit_5fx_5',['UNIT_X',['../struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#adeeb454e50949d89f71b52a38e52951e',1,'Ogre::VectorBase&lt; 2, Real &gt;::UNIT_X'],['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2fe25096ba980b3569e44833ddf155e6',1,'Ogre::VectorBase&lt; 3, Real &gt;::UNIT_X']]],
+  ['unit_5fy_6',['UNIT_Y',['../struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ab771b243b99665aaff02505c273be9ee',1,'Ogre::VectorBase&lt; 2, Real &gt;::UNIT_Y'],['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a25a0d767f153bc408453ee85de866c87',1,'Ogre::VectorBase&lt; 3, Real &gt;::UNIT_Y']]],
   ['unit_5fz_7',['UNIT_Z',['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ab8448c3f1c0a210e465a1aa0e551a33a',1,'Ogre::VectorBase&lt; 3, Real &gt;']]],
   ['unknown_8',['unknown',['../structbsp__face__t.html#adf2e01928d721064f72ba3f9c2e6a2fd',1,'bsp_face_t']]],
   ['updatefrom_9',['updateFrom',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#aeefacd1d618206fcb432ed947b58e06e',1,'Ogre::Volume::ChunkParameters']]],
@@ -16,12 +16,11 @@ var searchData=
   ['usecompression_13',['useCompression',['../struct_ogre_1_1_lod_config_1_1_advanced.html#a170e01ea28652c19ec4d610c0b491ab7',1,'Ogre::LodConfig::Advanced']]],
   ['usedcount_14',['usedCount',['../struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a433c84c8a42109d4f1e0987c063b0eee',1,'Ogre::Lod0Stripifier::RemapInfo']]],
   ['usefullscreen_15',['useFullScreen',['../struct_ogre_1_1_render_window_description.html#a5809e1727a29bbc2737e090ab338c6a7',1,'Ogre::RenderWindowDescription']]],
-  ['useglobalinstancingvertexbufferisavailable_16',['useGlobalInstancingVertexBufferIsAvailable',['../class_ogre_1_1_render_operation.html#a58effcf80fb468f10360aeab08d3c32e',1,'Ogre::RenderOperation']]],
+  ['useglobalinstancing_16',['useGlobalInstancing',['../class_ogre_1_1_render_operation.html#a7646ad7a394e7bb74aac8d55515f3975',1,'Ogre::RenderOperation']]],
   ['useindexes_17',['useIndexes',['../class_ogre_1_1_render_operation.html#ae12d3ff9f224f21738fa50f832484f3d',1,'Ogre::RenderOperation']]],
   ['userkey_18',['UserKey',['../class_ogre_1_1_r_t_shader_1_1_target_render_state.html#ad89fc9a3c7ec0c73a5d7805013547c24',1,'Ogre::RTShader::TargetRenderState']]],
   ['uservalue_19',['userValue',['../struct_ogre_1_1_mesh_lod_usage.html#a114e1bc321b7b64f5bc931a30fea4dfe',1,'Ogre::MeshLodUsage']]],
-  ['usesharedvertexbuffer_20',['useSharedVertexBuffer',['../struct_ogre_1_1_lod_input_buffer_1_1_submesh.html#a575926e31feb1cc9bfebab8a13fded97',1,'Ogre::LodInputBuffer::Submesh']]],
-  ['usesharedvertices_21',['useSharedVertices',['../class_ogre_1_1_sub_mesh.html#a931e3764e3bf1c3ef7431fc852770fb1',1,'Ogre::SubMesh']]],
-  ['usevertexnormals_22',['useVertexNormals',['../struct_ogre_1_1_lod_config_1_1_advanced.html#aa510662a645fab3ef85ef4b1cde1a7a2',1,'Ogre::LodConfig::Advanced']]],
-  ['uvrect_23',['uvRect',['../struct_ogre_1_1_glyph_info.html#a84b183865a26dd978207ade16075f075',1,'Ogre::GlyphInfo']]]
+  ['usesharedvertices_20',['useSharedVertices',['../class_ogre_1_1_sub_mesh.html#a931e3764e3bf1c3ef7431fc852770fb1',1,'Ogre::SubMesh']]],
+  ['usevertexnormals_21',['useVertexNormals',['../struct_ogre_1_1_lod_config_1_1_advanced.html#aa510662a645fab3ef85ef4b1cde1a7a2',1,'Ogre::LodConfig::Advanced']]],
+  ['uvrect_22',['uvRect',['../struct_ogre_1_1_glyph_info.html#a84b183865a26dd978207ade16075f075',1,'Ogre::GlyphInfo']]]
 ];
