@@ -6,12 +6,12 @@ var searchData=
   ['lasttransitiondist_3',['lastTransitionDist',['../struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#ac82a3ddf378272493d9d82100c17597a',1,'Ogre::TerrainQuadTreeNode::LodLevel']]],
   ['layerdeclaration_4',['layerDeclaration',['../struct_ogre_1_1_terrain_1_1_import_data.html#ae3203cf7a78bd3ed0cd75ffe3c107a2e',1,'Ogre::Terrain::ImportData']]],
   ['layerlist_5',['layerList',['../struct_ogre_1_1_terrain_1_1_import_data.html#a3d892ce610f8e6aec873528d042fe72b',1,'Ogre::Terrain::ImportData']]],
-  ['left_6',['left',['../struct_ogre_1_1_t_rect.html#a7f8310e37638f8790a89f2dd64ff3fe1',1,'Ogre::TRect::left()'],['../struct_ogre_1_1_box.html#a88fa61f841bc444d92075d8b6cb2b43b',1,'Ogre::Box::left()']]],
+  ['left_6',['left',['../struct_ogre_1_1_t_rect.html#a7f8310e37638f8790a89f2dd64ff3fe1',1,'Ogre::TRect::left'],['../struct_ogre_1_1_box.html#a88fa61f841bc444d92075d8b6cb2b43b',1,'Ogre::Box::left']]],
   ['length_7',['length',['../struct_ogre_1_1_stream_serialiser_1_1_chunk.html#aee59026e7658bc15408b2f92ee1140cb',1,'Ogre::StreamSerialiser::Chunk']]],
-  ['level_8',['level',['../struct_ogre_1_1_volume_1_1_chunk_request.html#ae5e6c6ee00b6c824bcc782266a440c42',1,'Ogre::Volume::ChunkRequest']]],
-  ['levels_9',['levels',['../struct_ogre_1_1_lod_config.html#a7eecc87589b5a3eacfa363850c2fe4c0',1,'Ogre::LodConfig']]],
-  ['lightmap_10',['lightmap',['../structbsp__vertex__t.html#a356f6ae529d0d3bef03e187320ea099a',1,'bsp_vertex_t']]],
-  ['line_11',['line',['../class_ogre_1_1_abstract_node.html#ad2e2e1cc95ee64cd9632cc63e4ca3234',1,'Ogre::AbstractNode::line()'],['../struct_ogre_1_1_concrete_node.html#a444a4c821038a26b6b35aafdf28ca965',1,'Ogre::ConcreteNode::line()']]],
+  ['levels_8',['levels',['../struct_ogre_1_1_lod_config.html#a7eecc87589b5a3eacfa363850c2fe4c0',1,'Ogre::LodConfig']]],
+  ['lightmap_9',['lightmap',['../structbsp__vertex__t.html#a356f6ae529d0d3bef03e187320ea099a',1,'bsp_vertex_t']]],
+  ['line_10',['line',['../struct_ogre_1_1_concrete_node.html#a444a4c821038a26b6b35aafdf28ca965',1,'Ogre::ConcreteNode::line'],['../class_ogre_1_1_abstract_node.html#ad2e2e1cc95ee64cd9632cc63e4ca3234',1,'Ogre::AbstractNode::line']]],
+  ['lines_11',['lines',['../struct_ogre_1_1_lod_data_1_1_vertex.html#a54d42759d6ab25e25bd52d34a7e656c6',1,'Ogre::LodData::Vertex']]],
   ['lm_5foffset_12',['lm_offset',['../structbsp__face__t.html#aac42a7e77d3bdd9a6a9e4865201a7d1e',1,'bsp_face_t']]],
   ['lm_5fsize_13',['lm_size',['../structbsp__face__t.html#ac295aee82ef83a80e6fb6e4123fccd32',1,'bsp_face_t']]],
   ['lm_5ftexture_14',['lm_texture',['../structbsp__face__t.html#a26742ad3555447b16d7d84a200df90e4',1,'bsp_face_t']]],
@@ -19,7 +19,7 @@ var searchData=
   ['lod_5fmorph_5fcustom_5fparam_16',['LOD_MORPH_CUSTOM_PARAM',['../class_ogre_1_1_terrain.html#acc4dccaad096e6d2abb01dd4813b18d5',1,'Ogre::Terrain']]],
   ['lodbias_17',['lodBias',['../class_ogre_1_1_compositor_instance_1_1_target_operation.html#a8ba9a8940b2e81cb3e866cce28697a4f',1,'Ogre::CompositorInstance::TargetOperation']]],
   ['lodcallback_18',['lodCallback',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#a6403e2875cc7b81aefd43ba9f22c2b31',1,'Ogre::Volume::ChunkParameters']]],
-  ['lodvalue_19',['lodValue',['../struct_ogre_1_1_entity_mesh_lod_changed_event.html#a296d3f28b84001e84a6153a6b8892dc7',1,'Ogre::EntityMeshLodChangedEvent::lodValue()'],['../struct_ogre_1_1_entity_material_lod_changed_event.html#a9f6f11b3dc3989fc136e7796b8c9669c',1,'Ogre::EntityMaterialLodChangedEvent::lodValue()']]],
+  ['lodvalue_19',['lodValue',['../struct_ogre_1_1_entity_mesh_lod_changed_event.html#a296d3f28b84001e84a6153a6b8892dc7',1,'Ogre::EntityMeshLodChangedEvent::lodValue'],['../struct_ogre_1_1_entity_material_lod_changed_event.html#a9f6f11b3dc3989fc136e7796b8c9669c',1,'Ogre::EntityMaterialLodChangedEvent::lodValue']]],
   ['log2_20',['LOG2',['../class_ogre_1_1_math.html#ad6c71292d588ec47d0ef82babd95d1d7',1,'Ogre::Math']]],
   ['logicalindex_21',['logicalIndex',['../struct_ogre_1_1_gpu_constant_definition.html#a8579926ecde16841abf0d872689b672c',1,'Ogre::GpuConstantDefinition']]],
   ['lumps_22',['lumps',['../structbsp__header__t.html#a3ebea24b318355e48c5035bdca0cfd1c',1,'bsp_header_t']]]
